# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/metadataservice/metadata_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tecton_proto.data import fco_pb2 as tecton__proto_dot_data_dot_fco__pb2
from tecton_proto.data import state_update_pb2 as tecton__proto_dot_data_dot_state__update__pb2
from tecton_proto.data import entity_pb2 as tecton__proto_dot_data_dot_entity__pb2
from tecton_proto.data import user_deployment_settings_pb2 as tecton__proto_dot_data_dot_user__deployment__settings__pb2
from tecton_proto.data import feature_view_pb2 as tecton__proto_dot_data_dot_feature__view__pb2
from tecton_proto.data import feature_service_pb2 as tecton__proto_dot_data_dot_feature__service__pb2
from tecton_proto.data import tecton_api_key_pb2 as tecton__proto_dot_data_dot_tecton__api__key__pb2
from tecton_proto.data import user_pb2 as tecton__proto_dot_data_dot_user__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import fco_locator_pb2 as tecton__proto_dot_common_dot_fco__locator__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2
from tecton_proto.data import materialization_status_pb2 as tecton__proto_dot_data_dot_materialization__status__pb2
from tecton_proto.data import freshness_status_pb2 as tecton__proto_dot_data_dot_freshness__status__pb2
from tecton_proto.data import serving_status_pb2 as tecton__proto_dot_data_dot_serving__status__pb2
from tecton_proto.data import summary_pb2 as tecton__proto_dot_data_dot_summary__pb2
from tecton_proto.data import saved_feature_data_frame_pb2 as tecton__proto_dot_data_dot_saved__feature__data__frame__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import workspace_pb2 as tecton__proto_dot_data_dot_workspace__pb2
from tecton_proto.amplitude import client_logging_pb2 as tecton__proto_dot_amplitude_dot_client__logging__pb2
from tecton_proto.amplitude import amplitude_pb2 as tecton__proto_dot_amplitude_dot_amplitude__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/metadataservice/metadata_service.proto',
  package='tecton_proto.metadataservice',
  syntax='proto2',
  serialized_options=b'\n\032com.tecton.metadataserviceB\024MetadataServiceProtoP\001Z1github.com/tecton-ai/tecton_proto/metadataservice',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3tecton_proto/metadataservice/metadata_service.proto\x12\x1ctecton_proto.metadataservice\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1btecton_proto/data/fco.proto\x1a$tecton_proto/data/state_update.proto\x1a\x1etecton_proto/data/entity.proto\x1a\x30tecton_proto/data/user_deployment_settings.proto\x1a$tecton_proto/data/feature_view.proto\x1a\'tecton_proto/data/feature_service.proto\x1a&tecton_proto/data/tecton_api_key.proto\x1a\x1ctecton_proto/data/user.proto\x1a\x1ctecton_proto/common/id.proto\x1a%tecton_proto/common/fco_locator.proto\x1a&tecton_proto/common/spark_schema.proto\x1a.tecton_proto/data/materialization_status.proto\x1a(tecton_proto/data/freshness_status.proto\x1a&tecton_proto/data/serving_status.proto\x1a\x1ftecton_proto/data/summary.proto\x1a\x30tecton_proto/data/saved_feature_data_frame.proto\x1a*tecton_proto/data/new_transformation.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a!tecton_proto/data/workspace.proto\x1a+tecton_proto/amplitude/client_logging.proto\x1a&tecton_proto/amplitude/amplitude.proto\"\xcc\x01\n\x18GetFeatureServiceRequest\x12+\n\x11service_reference\x18\x02 \x01(\tR\x10serviceReference\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponseJ\x04\x08\x01\x10\x02\"\xb1\x01\n\x19GetFeatureServiceResponse\x12N\n\x0f\x66\x65\x61ture_service\x18\x01 \x01(\x0b\x32!.tecton_proto.data.FeatureServiceB\x02\x18\x01R\x0e\x66\x65\x61tureService\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"<\n\x1cGetAllFeatureServicesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"m\n\x1dGetAllFeatureServicesResponse\x12L\n\x10\x66\x65\x61ture_services\x18\x01 \x03(\x0b\x32!.tecton_proto.data.FeatureServiceR\x0f\x66\x65\x61tureServices\"\xc7\x01\n\x1fGetFeatureServiceSummaryRequest\x12G\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\t\n\x07locator\"\x80\x02\n GetFeatureServiceSummaryResponse\x12\x43\n\rgeneral_items\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x0cgeneralItems\x12r\n\x1b\x66ull_serving_status_summary\x18\x02 \x01(\x0b\x32\x33.tecton_proto.data.FullFeatureServiceServingSummaryR\x18\x66ullServingStatusSummary\x12#\n\rvariant_names\x18\x03 \x03(\tR\x0cvariantNames\"f\n\"GetVirtualDataSourceSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"e\n#GetVirtualDataSourceSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"c\n\x1fGetTransformationSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"b\n GetTransformationSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"[\n\x17GetEntitySummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"Z\n\x18GetEntitySummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"\xd9\x01\n\x17GetServingStatusRequest\x12G\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0e\n\x0crequest_type\"y\n\x18GetServingStatusResponse\x12]\n\x16serving_status_summary\x18\x05 \x01(\x0b\x32\'.tecton_proto.data.ServingStatusSummaryR\x14servingStatusSummary\"=\n\x1dGetAllFeatureFreshnessRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"s\n\x1eGetAllFeatureFreshnessResponse\x12Q\n\x12\x66reshness_statuses\x18\x01 \x03(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x11\x66reshnessStatuses\"^\n\x1aGetFeatureFreshnessRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"l\n\x1bGetFeatureFreshnessResponse\x12M\n\x10\x66reshness_status\x18\x01 \x01(\x0b\x32\".tecton_proto.data.FreshnessStatusR\x0f\x66reshnessStatus\"h\n\x1fGetMaterializationStatusRequest\x12\x45\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61turePackageId\"\x83\x01\n GetMaterializationStatusResponse\x12_\n\x16materialization_status\x18\x01 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"V\n2GetAllMaterializationStatusInLiveWorkspacesRequest\x12 \n\x0c\x63ut_off_days\x18\x01 \x01(\x05R\ncutOffDays\"\xc5\x01\n FeatureViewMaterializationStatus\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12_\n\x16materialization_status\x18\x02 \x01(\x0b\x32(.tecton_proto.data.MaterializationStatusR\x15materializationStatus\"\xc5\x01\n3GetAllMaterializationStatusInLiveWorkspacesResponse\x12\x8d\x01\n#feature_view_materialization_status\x18\x01 \x03(\x0b\x32>.tecton_proto.metadataservice.FeatureViewMaterializationStatusR featureViewMaterializationStatus\"w\n$ForceRetryMaterializationTaskRequest\x12O\n\x17materialization_task_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x15materializationTaskId\"L\n%ForceRetryMaterializationTaskResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\".\n\x0eGetFcosRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"W\n\x0fGetFcosResponse\x12\x44\n\rfco_container\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"\xc3\x01\n\x15GetFeatureViewRequest\x12+\n\x11version_specifier\x18\x01 \x01(\tR\x10versionSpecifier\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\'\n\x02id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponse\"\xa5\x01\n\x16GetFeatureViewResponse\x12\x45\n\x0c\x66\x65\x61ture_view\x18\x01 \x01(\x0b\x32\x1e.tecton_proto.data.FeatureViewB\x02\x18\x01R\x0b\x66\x65\x61tureView\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"`\n\x1cGetFeatureViewSummaryRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\"_\n\x1dGetFeatureViewSummaryResponse\x12>\n\x0b\x66\x63o_summary\x18\x01 \x01(\x0b\x32\x1d.tecton_proto.data.FcoSummaryR\nfcoSummary\"\x84\x01\n\x18QueryFeatureViewsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponse\"\xaa\x01\n\x19QueryFeatureViewsResponse\x12G\n\rfeature_views\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.FeatureViewB\x02\x18\x01R\x0c\x66\x65\x61tureViews\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"{\n4GetMaterializingFeatureViewsInLiveWorkspacesResponse\x12\x43\n\rfeature_views\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.FeatureViewR\x0c\x66\x65\x61tureViews\"\xec\x01\n\x1bGetVirtualDataSourceRequest\x12N\n\x16virtual_data_source_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x13virtualDataSourceId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponseB\x11\n\x0fidentifier_type\"\xba\x01\n\x1cGetVirtualDataSourceResponse\x12T\n\x13virtual_data_source\x18\x01 \x01(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x11virtualDataSource\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"?\n\x1fGetAllVirtualDataSourcesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n GetAllVirtualDataSourcesResponse\x12V\n\x14virtual_data_sources\x18\x01 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\"\xc9\x01\n\x10GetEntityRequest\x12\x36\n\tentity_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x08\x65ntityId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponseB\x11\n\x0fidentifier_type\"\x8c\x01\n\x11GetEntityResponse\x12\x31\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.tecton_proto.data.EntityR\x06\x65ntity\x12\x44\n\rfco_container\x18\x02 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainer\"5\n\x15GetAllEntitiesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"O\n\x16GetAllEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.tecton_proto.data.EntityR\x08\x65ntities\"\xe1\x01\n\x18GetTransformationRequest\x12\x46\n\x11transformation_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10transformationId\x12\x14\n\x04name\x18\x02 \x01(\tH\x00R\x04name\x12\x1c\n\tworkspace\x18\x04 \x01(\tR\tworkspace\x12\x36\n\x17\x64isable_legacy_response\x18\x05 \x01(\x08R\x15\x64isableLegacyResponseB\x11\n\x0fidentifier_type\"\xbc\x01\n\x19GetTransformationResponse\x12S\n\x12new_transformation\x18\x02 \x01(\x0b\x32$.tecton_proto.data.NewTransformationR\x11newTransformation\x12\x44\n\rfco_container\x18\x03 \x01(\x0b\x32\x1f.tecton_proto.data.FcoContainerR\x0c\x66\x63oContainerJ\x04\x08\x01\x10\x02\"<\n\x1cGetAllTransformationsRequest\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"|\n\x1dGetAllTransformationsResponse\x12U\n\x13new_transformations\x18\x02 \x03(\x0b\x32$.tecton_proto.data.NewTransformationR\x12newTransformationsJ\x04\x08\x01\x10\x02\"B\n\x17\x46indFcoWorkspaceRequest\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"8\n\x18\x46indFcoWorkspaceResponse\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"z\n\x17IngestClientLogsRequest\x12_\n\x15sdk_method_invocation\x18\x01 \x01(\x0b\x32+.tecton_proto.amplitude.SDKMethodInvocationR\x13sdkMethodInvocation\"v\n\x16IngestAnalyticsRequest\x12>\n\x06\x65vents\x18\x01 \x03(\x0b\x32&.tecton_proto.amplitude.AmplitudeEventR\x06\x65vents\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\x8b\x01\n\x15NewStateUpdateRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32%.tecton_proto.data.StateUpdateRequestR\x07request\x12\x31\n\x15\x62locking_dry_run_mode\x18\x02 \x01(\x08R\x12\x62lockingDryRunMode\"\x84\x02\n\x16NewStateUpdateResponse\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12:\n\x1asigned_url_for_repo_upload\x18\x02 \x01(\tR\x16signedUrlForRepoUpload\x12z\n\x1e\x62locking_dry_run_mode_response\x18\x03 \x01(\x0b\x32\x36.tecton_proto.metadataservice.QueryStateUpdateResponseR\x1a\x62lockingDryRunModeResponse\"k\n\x17QueryStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\xa1\x02\n\x18QueryStateUpdateResponse\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12P\n\x11validation_result\x18\x04 \x01(\x0b\x32#.tecton_proto.data.ValidationResultR\x10validationResult\x12\x39\n\ndiff_items\x18\x05 \x03(\x0b\x32\x1a.tecton_proto.data.FcoDiffR\tdiffItems\x12\x32\n\x15latest_status_message\x18\x06 \x01(\tR\x13latestStatusMessage\"p\n\x17\x41pplyStateUpdateRequest\x12\x32\n\x08state_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x07stateId\x12!\n\napplied_by\x18\x02 \x01(\tB\x02\x18\x01R\tappliedBy\"\x1a\n\x18\x41pplyStateUpdateResponse\"\xb2\x01\n\x12GetConfigsResponse\x12^\n\nkey_values\x18\x01 \x03(\x0b\x32?.tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntryR\tkeyValues\x1a<\n\x0eKeyValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"N\n\x18GetStateUpdateLogRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"Z\n\x19GetStateUpdateLogResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.tecton_proto.data.StateUpdateEntryR\x07\x65ntries\"R\n\x15GetRestoreInfoRequest\x12\x1b\n\tcommit_id\x18\x01 \x01(\tR\x08\x63ommitId\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\"\x96\x01\n\x16GetRestoreInfoResponse\x12>\n\x1csigned_url_for_repo_download\x18\x01 \x01(\tR\x18signedUrlForRepoDownload\x12\x1b\n\tcommit_id\x18\x02 \x01(\tR\x08\x63ommitId\x12\x1f\n\x0bsdk_version\x18\x03 \x01(\tR\nsdkVersion\"\x93\x01\n\x16\x43reateWorkspaceRequest\x12%\n\x0eworkspace_name\x18\x02 \x01(\tR\rworkspaceName\x12L\n\x0c\x63\x61pabilities\x18\x03 \x01(\x0b\x32(.tecton_proto.data.WorkspaceCapabilitiesR\x0c\x63\x61pabilitiesJ\x04\x08\x01\x10\x02\"6\n\x16\x44\x65leteWorkspaceRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"R\n\x13\x43reateApiKeyRequest\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08is_admin\x18\x02 \x01(\x08R\x07isAdmin\"(\n\x14\x43reateApiKeyResponse\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\">\n\x13\x44\x65leteApiKeyRequest\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\"?\n\x12ListApiKeysRequest\x12)\n\x10include_archived\x18\x01 \x01(\x08R\x0fincludeArchived\"Q\n\x13ListApiKeysResponse\x12:\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x1f.tecton_proto.data.TectonApiKeyR\x07\x61piKeys\"\x17\n\x15ListWorkspacesRequest\"V\n\x16ListWorkspacesResponse\x12<\n\nworkspaces\x18\x01 \x03(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\nworkspaces\"<\n\x13GetWorkspaceRequest\x12%\n\x0eworkspace_name\x18\x01 \x01(\tR\rworkspaceName\"R\n\x14GetWorkspaceResponse\x12:\n\tworkspace\x18\x01 \x01(\x0b\x32\x1c.tecton_proto.data.WorkspaceR\tworkspace\"\x93\x03\n\"CreateSavedFeatureDataFrameRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tworkspace\x18\x07 \x01(\tR\tworkspace\x12G\n\x12\x66\x65\x61ture_package_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x03 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x31\n\x15join_key_column_names\x18\x04 \x03(\tR\x12joinKeyColumnNames\x12\x32\n\x15timestamp_column_name\x18\x05 \x01(\tR\x13timestampColumnName\x12\x38\n\x06schema\x18\x06 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x06schemaB\x08\n\x06source\"\x87\x01\n#CreateSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"{\n#ArchiveSavedFeatureDataFrameRequest\x12T\n\x1asaved_feature_dataframe_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x17savedFeatureDataframeId\"&\n$ArchiveSavedFeatureDataFrameResponse\"\xe7\x01\n\x1fGetSavedFeatureDataFrameRequest\x12\x41\n\x1csaved_feature_dataframe_name\x18\x01 \x01(\tH\x00R\x19savedFeatureDataframeName\x12V\n\x1asaved_feature_dataframe_id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x17savedFeatureDataframeId\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\x0b\n\treference\"\xa5\x01\n\x1bGetClusterAdminInfoResponse\x12&\n\x0f\x63\x61ller_is_admin\x18\x01 \x01(\x08R\rcallerIsAdmin\x12-\n\x05users\x18\x02 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x05users\x12/\n\x06\x61\x64mins\x18\x03 \x03(\x0b\x32\x17.tecton_proto.data.UserR\x06\x61\x64mins\";\n\x18\x43reateClusterUserRequest\x12\x1f\n\x0blogin_email\x18\x01 \x01(\tR\nloginEmail\"@\n\x19\x43reateClusterUserResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"3\n\x18\x44\x65leteClusterUserRequest\x12\x17\n\x07okta_id\x18\x01 \x01(\tR\x06oktaId\"@\n\x19\x44\x65leteClusterUserResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\xe2\x01\n\x18\x43lusterUserActionRequest\x12\x17\n\x07okta_id\x18\x01 \x01(\tR\x06oktaId\x12\x38\n\x17resend_activation_email\x18\x02 \x01(\x08H\x00R\x15resendActivationEmail\x12!\n\x0bunlock_user\x18\x03 \x01(\x08H\x00R\nunlockUser\x12!\n\x0bgrant_admin\x18\x04 \x01(\x08H\x00R\ngrantAdmin\x12#\n\x0crevoke_admin\x18\x05 \x01(\x08H\x00R\x0brevokeAdminB\x08\n\x06\x61\x63tion\"@\n\x19\x43lusterUserActionResponse\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\x84\x01\n GetSavedFeatureDataFrameResponse\x12`\n\x17saved_feature_dataframe\x18\x01 \x01(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x15savedFeatureDataframe\"C\n#GetAllSavedFeatureDataFramesRequest\x12\x1c\n\tworkspace\x18\x01 \x01(\tR\tworkspace\"\x8a\x01\n$GetAllSavedFeatureDataFramesResponse\x12\x62\n\x18saved_feature_dataframes\x18\x01 \x03(\x0b\x32(.tecton_proto.data.SavedFeatureDataFrameR\x16savedFeatureDataframes\"\x9c\x01\n\x16IngestDataframeRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\x12\x17\n\x07\x64\x66_path\x18\x02 \x01(\tR\x06\x64\x66Path\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspace\"\x19\n\x17IngestDataframeResponse\"o\n GetNewIngestDataframeInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"t\n!GetNewIngestDataframeInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x36\n\x18signed_url_for_df_upload\x18\x02 \x01(\tR\x14signedUrlForDfUpload\"\x88\x01\n!GetUserDeploymentSettingsResponse\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\"\x8a\x01\n#UpdateUserDeploymentSettingsRequest\x12\x63\n\x18user_deployment_settings\x18\x01 \x01(\x0b\x32).tecton_proto.data.UserDeploymentSettingsR\x16userDeploymentSettings\"e\n$UpdateUserDeploymentSettingsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x02 \x01(\tR\x0c\x65rrorMessage\"\x9b\x03\n%GetInternalSparkClusterStatusResponse\x12v\n\x06status\x18\x01 \x01(\x0e\x32^.tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse.InternalSparkClusterStatusR\x06status\"\xf9\x01\n\x1aInternalSparkClusterStatus\x12)\n%INTERNAL_SPARK_CLUSTER_STATUS_UNKNOWN\x10\x00\x12)\n%INTERNAL_SPARK_CLUSTER_STATUS_HEALTHY\x10\x01\x12+\n\'INTERNAL_SPARK_CLUSTER_STATUS_UNHEALTHY\x10\x02\x12*\n&INTERNAL_SPARK_CLUSTER_STATUS_STARTING\x10\x03\x12,\n(INTERNAL_SPARK_CLUSTER_STATUS_NO_CLUSTER\x10\x04\"k\n\x1cGetDeleteEntitiesInfoRequest\x12K\n\x15\x66\x65\x61ture_definition_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13\x66\x65\x61tureDefinitionId\"p\n\x1dGetDeleteEntitiesInfoResponse\x12\x17\n\x07\x64\x66_path\x18\x01 \x01(\tR\x06\x64\x66Path\x12\x36\n\x18signed_url_for_df_upload\x18\x02 \x01(\tR\x14signedUrlForDfUpload\"\xf3\x01\n\x15\x44\x65leteEntitiesRequest\x12@\n\x0b\x66\x63o_locator\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\nfcoLocator\x12\x31\n\x15online_join_keys_path\x18\x02 \x01(\tR\x12onlineJoinKeysPath\x12\x33\n\x16offline_join_keys_path\x18\x03 \x01(\tR\x13offlineJoinKeysPath\x12\x16\n\x06online\x18\x04 \x01(\x08R\x06online\x12\x18\n\x07offline\x18\x05 \x01(\x08R\x07offline\"\x18\n\x16\x44\x65leteEntitiesResponse2\xb8K\n\x0fMetadataService\x12\xbd\x01\n\x11GetFeatureService\x12\x36.tecton_proto.metadataservice.GetFeatureServiceRequest\x1a\x37.tecton_proto.metadataservice.GetFeatureServiceResponse\"7\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/get-feature-service:\x01*\x80\xb5\x18\x01\x12\xce\x01\n\x15GetAllFeatureServices\x12:.tecton_proto.metadataservice.GetAllFeatureServicesRequest\x1a;.tecton_proto.metadataservice.GetAllFeatureServicesResponse\"<\x82\xd3\xe4\x93\x02\x32\"-/v1/metadata-service/get-all-feature-services:\x01*\x80\xb5\x18\x01\x12\xda\x01\n\x18GetFeatureServiceSummary\x12=.tecton_proto.metadataservice.GetFeatureServiceSummaryRequest\x1a>.tecton_proto.metadataservice.GetFeatureServiceSummaryResponse\"?\x82\xd3\xe4\x93\x02\x35\"0/v1/metadata-service/get-feature-service-summary:\x01*\x80\xb5\x18\x01\x12\xb9\x01\n\x10GetServingStatus\x12\x35.tecton_proto.metadataservice.GetServingStatusRequest\x1a\x36.tecton_proto.metadataservice.GetServingStatusResponse\"6\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/get-serving-status:\x01*\x80\xb5\x18\x01\x12\xd2\x01\n\x16GetAllFeatureFreshness\x12;.tecton_proto.metadataservice.GetAllFeatureFreshnessRequest\x1a<.tecton_proto.metadataservice.GetAllFeatureFreshnessResponse\"=\x82\xd3\xe4\x93\x02\x33\"./v1/metadata-service/get-all-feature-freshness:\x01*\x80\xb5\x18\x01\x12\xc5\x01\n\x13GetFeatureFreshness\x12\x38.tecton_proto.metadataservice.GetFeatureFreshnessRequest\x1a\x39.tecton_proto.metadataservice.GetFeatureFreshnessResponse\"9\x82\xd3\xe4\x93\x02/\"*/v1/metadata-service/get-feature-freshness:\x01*\x80\xb5\x18\x01\x12\xd9\x01\n\x18GetMaterializationStatus\x12=.tecton_proto.metadataservice.GetMaterializationStatusRequest\x1a>.tecton_proto.metadataservice.GetMaterializationStatusResponse\">\x82\xd3\xe4\x93\x02\x34\"//v1/metadata-service/get-materialization-status:\x01*\x80\xb5\x18\x01\x12\xa8\x02\n+GetAllMaterializationStatusInLiveWorkspaces\x12P.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest\x1aQ.tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse\"T\x82\xd3\xe4\x93\x02J\"E/v1/metadata-service/get-all-materialization-status-in-live-workspace:\x01*\x80\xb5\x18\x01\x12\xea\x01\n\x1d\x46orceRetryMaterializationTask\x12\x42.tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest\x1a\x43.tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse\"@\x82\xd3\xe4\x93\x02:\"5/v1/metadata-service/force-retry-materialization-task:\x01*\x12\xb1\x01\n\x0eGetFeatureView\x12\x33.tecton_proto.metadataservice.GetFeatureViewRequest\x1a\x34.tecton_proto.metadataservice.GetFeatureViewResponse\"4\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/get-feature-view:\x01*\x80\xb5\x18\x01\x12\xec\x01\n,GetMaterializingFeatureViewsInLiveWorkspaces\x12\x16.google.protobuf.Empty\x1aR.tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse\"P\x82\xd3\xe4\x93\x02\x46\"A/v1/metadata-service/get-materializing-features-in-live-workspace:\x01*\x80\xb5\x18\x01\x12\xbd\x01\n\x11QueryFeatureViews\x12\x36.tecton_proto.metadataservice.QueryFeatureViewsRequest\x1a\x37.tecton_proto.metadataservice.QueryFeatureViewsResponse\"7\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/query-feature-views:\x01*\x80\xb5\x18\x01\x12\xce\x01\n\x15GetFeatureViewSummary\x12:.tecton_proto.metadataservice.GetFeatureViewSummaryRequest\x1a;.tecton_proto.metadataservice.GetFeatureViewSummaryResponse\"<\x82\xd3\xe4\x93\x02\x32\"-/v1/metadata-package/get-feature-view-summary:\x01*\x80\xb5\x18\x01\x12\xca\x01\n\x14GetVirtualDataSource\x12\x39.tecton_proto.metadataservice.GetVirtualDataSourceRequest\x1a:.tecton_proto.metadataservice.GetVirtualDataSourceResponse\";\x82\xd3\xe4\x93\x02\x31\",/v1/metadata-service/get-virtual-data-source:\x01*\x80\xb5\x18\x01\x12\xdb\x01\n\x18GetAllVirtualDataSources\x12=.tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest\x1a>.tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse\"@\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-all-virtual-data-sources:\x01*\x80\xb5\x18\x01\x12g\n\x10IngestClientLogs\x12\x35.tecton_proto.metadataservice.IngestClientLogsRequest\x1a\x16.google.protobuf.Empty\"\x04\x80\xb5\x18\x01\x12\x95\x01\n\x0fIngestAnalytics\x12\x34.tecton_proto.metadataservice.IngestAnalyticsRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/ingest-analytics:\x01*\x80\xb5\x18\x01\x12\xe7\x01\n\x1bGetVirtualDataSourceSummary\x12@.tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest\x1a\x41.tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse\"C\x82\xd3\xe4\x93\x02\x39\"4/v1/metadata-service/get-virtual-data-source-summary:\x01*\x80\xb5\x18\x01\x12\x94\x01\n\x07GetFcos\x12,.tecton_proto.metadataservice.GetFcosRequest\x1a-.tecton_proto.metadataservice.GetFcosResponse\",\x82\xd3\xe4\x93\x02\"\"\x1d/v1/metadata-service/get-fcos:\x01*\x80\xb5\x18\x01\x12r\n\tGetEntity\x12..tecton_proto.metadataservice.GetEntityRequest\x1a/.tecton_proto.metadataservice.GetEntityResponse\"\x04\x80\xb5\x18\x01\x12\xb1\x01\n\x0eGetAllEntities\x12\x33.tecton_proto.metadataservice.GetAllEntitiesRequest\x1a\x34.tecton_proto.metadataservice.GetAllEntitiesResponse\"4\x82\xd3\xe4\x93\x02*\"%/v1/metadata-service/get-all-entities:\x01*\x80\xb5\x18\x01\x12\xb9\x01\n\x10GetEntitySummary\x12\x35.tecton_proto.metadataservice.GetEntitySummaryRequest\x1a\x36.tecton_proto.metadataservice.GetEntitySummaryResponse\"6\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-package/get-entity-summary:\x01*\x80\xb5\x18\x01\x12\xbc\x01\n\x11GetTransformation\x12\x36.tecton_proto.metadataservice.GetTransformationRequest\x1a\x37.tecton_proto.metadataservice.GetTransformationResponse\"6\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/get-transformation:\x01*\x80\xb5\x18\x01\x12\xcd\x01\n\x15GetAllTransformations\x12:.tecton_proto.metadataservice.GetAllTransformationsRequest\x1a;.tecton_proto.metadataservice.GetAllTransformationsResponse\";\x82\xd3\xe4\x93\x02\x31\",/v1/metadata-service/get-all-transformations:\x01*\x80\xb5\x18\x01\x12\xd9\x01\n\x18GetTransformationSummary\x12=.tecton_proto.metadataservice.GetTransformationSummaryRequest\x1a>.tecton_proto.metadataservice.GetTransformationSummaryResponse\">\x82\xd3\xe4\x93\x02\x34\"//v1/metadata-package/get-transformation-summary:\x01*\x80\xb5\x18\x01\x12\xb9\x01\n\x10\x46indFcoWorkspace\x12\x35.tecton_proto.metadataservice.FindFcoWorkspaceRequest\x1a\x36.tecton_proto.metadataservice.FindFcoWorkspaceResponse\"6\x82\xd3\xe4\x93\x02,\"\'/v1/metadata-service/find-fco-workspace:\x01*\x80\xb5\x18\x01\x12}\n\x0eNewStateUpdate\x12\x33.tecton_proto.metadataservice.NewStateUpdateRequest\x1a\x34.tecton_proto.metadataservice.NewStateUpdateResponse\"\x00\x12\x87\x01\n\x10QueryStateUpdate\x12\x35.tecton_proto.metadataservice.QueryStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.QueryStateUpdateResponse\"\x04\x80\xb5\x18\x01\x12\x83\x01\n\x10\x41pplyStateUpdate\x12\x35.tecton_proto.metadataservice.ApplyStateUpdateRequest\x1a\x36.tecton_proto.metadataservice.ApplyStateUpdateResponse\"\x00\x12\x87\x01\n\nGetConfigs\x12\x16.google.protobuf.Empty\x1a\x30.tecton_proto.metadataservice.GetConfigsResponse\"/\x82\xd3\xe4\x93\x02%\" /v1/metadata-service/get-configs:\x01*\x80\xb5\x18\x01\x12;\n\x03Nop\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x04\x80\xb5\x18\x01\x12\xbe\x01\n\x11GetStateUpdateLog\x12\x36.tecton_proto.metadataservice.GetStateUpdateLogRequest\x1a\x37.tecton_proto.metadataservice.GetStateUpdateLogResponse\"8\x82\xd3\xe4\x93\x02.\")/v1/metadata-service/get-state-update-log:\x01*\x80\xb5\x18\x01\x12\x81\x01\n\x0eGetRestoreInfo\x12\x33.tecton_proto.metadataservice.GetRestoreInfoRequest\x1a\x34.tecton_proto.metadataservice.GetRestoreInfoResponse\"\x04\x80\xb5\x18\x01\x12\x61\n\x0f\x43reateWorkspace\x12\x34.tecton_proto.metadataservice.CreateWorkspaceRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x61\n\x0f\x44\x65leteWorkspace\x12\x34.tecton_proto.metadataservice.DeleteWorkspaceRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb0\x01\n\x0eListWorkspaces\x12\x33.tecton_proto.metadataservice.ListWorkspacesRequest\x1a\x34.tecton_proto.metadataservice.ListWorkspacesResponse\"3\x82\xd3\xe4\x93\x02)\"$/v1/metadata-service/list-workspaces:\x01*\x80\xb5\x18\x01\x12\xa8\x01\n\x0cGetWorkspace\x12\x31.tecton_proto.metadataservice.GetWorkspaceRequest\x1a\x32.tecton_proto.metadataservice.GetWorkspaceResponse\"1\x82\xd3\xe4\x93\x02\'\"\"/v1/metadata-service/get-workspace:\x01*\x80\xb5\x18\x01\x12w\n\x0c\x43reateApiKey\x12\x31.tecton_proto.metadataservice.CreateApiKeyRequest\x1a\x32.tecton_proto.metadataservice.CreateApiKeyResponse\"\x00\x12[\n\x0c\x44\x65leteApiKey\x12\x31.tecton_proto.metadataservice.DeleteApiKeyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12x\n\x0bListApiKeys\x12\x30.tecton_proto.metadataservice.ListApiKeysRequest\x1a\x31.tecton_proto.metadataservice.ListApiKeysResponse\"\x04\x80\xb5\x18\x01\x12\xa8\x01\n\x1b\x43reateSavedFeatureDataFrame\x12@.tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest\x1a\x41.tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse\"\x04\x80\xb5\x18\x01\x12\xab\x01\n\x1c\x41rchiveSavedFeatureDataFrame\x12\x41.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest\x1a\x42.tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameResponse\"\x04\x80\xb5\x18\x01\x12\x9f\x01\n\x18GetSavedFeatureDataFrame\x12=.tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest\x1a>.tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse\"\x04\x80\xb5\x18\x01\x12\xeb\x01\n\x1cGetAllSavedFeatureDataFrames\x12\x41.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest\x1a\x42.tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse\"D\x82\xd3\xe4\x93\x02:\"5/v1/metadata-service/get-all-saved-feature-dataframes:\x01*\x80\xb5\x18\x01\x12\xa2\x01\n\x19GetNewIngestDataframeInfo\x12>.tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest\x1a?.tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse\"\x04\x80\xb5\x18\x01\x12\x84\x01\n\x0fIngestDataframe\x12\x34.tecton_proto.metadataservice.IngestDataframeRequest\x1a\x35.tecton_proto.metadataservice.IngestDataframeResponse\"\x04\x80\xb5\x18\x01\x12\xa4\x01\n\x13GetClusterAdminInfo\x12\x16.google.protobuf.Empty\x1a\x39.tecton_proto.metadataservice.GetClusterAdminInfoResponse\":\x82\xd3\xe4\x93\x02\x30\"+/v1/metadata-service/get-cluster-admin-info:\x01*\x80\xb5\x18\x01\x12\xb9\x01\n\x11\x43reateClusterUser\x12\x36.tecton_proto.metadataservice.CreateClusterUserRequest\x1a\x37.tecton_proto.metadataservice.CreateClusterUserResponse\"3\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/create-cluster-user:\x01*\x12\xb9\x01\n\x11\x44\x65leteClusterUser\x12\x36.tecton_proto.metadataservice.DeleteClusterUserRequest\x1a\x37.tecton_proto.metadataservice.DeleteClusterUserResponse\"3\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/delete-cluster-user:\x01*\x12\xb9\x01\n\x11\x43lusterUserAction\x12\x36.tecton_proto.metadataservice.ClusterUserActionRequest\x1a\x37.tecton_proto.metadataservice.ClusterUserActionResponse\"3\x82\xd3\xe4\x93\x02-\"(/v1/metadata-service/cluster-user-action:\x01*\x12\xb6\x01\n\x19GetUserDeploymentSettings\x12\x16.google.protobuf.Empty\x1a?.tecton_proto.metadataservice.GetUserDeploymentSettingsResponse\"@\x82\xd3\xe4\x93\x02\x36\"1/v1/metadata-service/get-user-deployment-settings:\x01*\x80\xb5\x18\x01\x12\xe6\x01\n\x1cUpdateUserDeploymentSettings\x12\x41.tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest\x1a\x42.tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v1/metadata-service/update-user-deployment-settings:\x01*\x12\xbf\x01\n\x1dGetInternalSparkClusterStatus\x12\x16.google.protobuf.Empty\x1a\x43.tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse\"A\x82\xd3\xe4\x93\x02;\"6/v1/metadata-service/get-internal-spark-cluster-status:\x01*\x12\x96\x01\n\x15GetDeleteEntitiesInfo\x12:.tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest\x1a;.tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse\"\x04\x80\xb5\x18\x01\x12\x81\x01\n\x0e\x44\x65leteEntities\x12\x33.tecton_proto.metadataservice.DeleteEntitiesRequest\x1a\x34.tecton_proto.metadataservice.DeleteEntitiesResponse\"\x04\x80\xb5\x18\x01:e\n\x1b\x61llow_in_standard_user_role\x12\x1e.google.protobuf.MethodOptions\x18\xd0\x86\x03 \x01(\x08:\x05\x66\x61lseR\x17\x61llowInStandardUserRoleBg\n\x1a\x63om.tecton.metadataserviceB\x14MetadataServiceProtoP\x01Z1github.com/tecton-ai/tecton_proto/metadataservice'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fco__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_state__update__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_entity__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_user__deployment__settings__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__service__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_tecton__api__key__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_user__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_fco__locator__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_materialization__status__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_freshness__status__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_serving__status__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_summary__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_saved__feature__data__frame__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_workspace__pb2.DESCRIPTOR,tecton__proto_dot_amplitude_dot_client__logging__pb2.DESCRIPTOR,tecton__proto_dot_amplitude_dot_amplitude__pb2.DESCRIPTOR,])


ALLOW_IN_STANDARD_USER_ROLE_FIELD_NUMBER = 50000
allow_in_standard_user_role = _descriptor.FieldDescriptor(
  name='allow_in_standard_user_role', full_name='tecton_proto.metadataservice.allow_in_standard_user_role', index=0,
  number=50000, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='allowInStandardUserRole', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

_GETINTERNALSPARKCLUSTERSTATUSRESPONSE_INTERNALSPARKCLUSTERSTATUS = _descriptor.EnumDescriptor(
  name='InternalSparkClusterStatus',
  full_name='tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse.InternalSparkClusterStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SPARK_CLUSTER_STATUS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SPARK_CLUSTER_STATUS_HEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SPARK_CLUSTER_STATUS_UNHEALTHY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SPARK_CLUSTER_STATUS_STARTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_SPARK_CLUSTER_STATUS_NO_CLUSTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12786,
  serialized_end=13035,
)
_sym_db.RegisterEnumDescriptor(_GETINTERNALSPARKCLUSTERSTATUSRESPONSE_INTERNALSPARKCLUSTERSTATUS)


_GETFEATURESERVICEREQUEST = _descriptor.Descriptor(
  name='GetFeatureServiceRequest',
  full_name='tecton_proto.metadataservice.GetFeatureServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_reference', full_name='tecton_proto.metadataservice.GetFeatureServiceRequest.service_reference', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serviceReference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetFeatureServiceRequest.workspace', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.metadataservice.GetFeatureServiceRequest.id', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.GetFeatureServiceRequest.disable_legacy_response', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1212,
)


_GETFEATURESERVICERESPONSE = _descriptor.Descriptor(
  name='GetFeatureServiceResponse',
  full_name='tecton_proto.metadataservice.GetFeatureServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service', full_name='tecton_proto.metadataservice.GetFeatureServiceResponse.feature_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='featureService', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetFeatureServiceResponse.fco_container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1215,
  serialized_end=1392,
)


_GETALLFEATURESERVICESREQUEST = _descriptor.Descriptor(
  name='GetAllFeatureServicesRequest',
  full_name='tecton_proto.metadataservice.GetAllFeatureServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllFeatureServicesRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1454,
)


_GETALLFEATURESERVICESRESPONSE = _descriptor.Descriptor(
  name='GetAllFeatureServicesResponse',
  full_name='tecton_proto.metadataservice.GetAllFeatureServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_services', full_name='tecton_proto.metadataservice.GetAllFeatureServicesResponse.feature_services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServices', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1456,
  serialized_end=1565,
)


_GETFEATURESERVICESUMMARYREQUEST = _descriptor.Descriptor(
  name='GetFeatureServiceSummaryRequest',
  full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryRequest.feature_service_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryRequest.feature_service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryRequest.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1568,
  serialized_end=1767,
)


_GETFEATURESERVICESUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetFeatureServiceSummaryResponse',
  full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='general_items', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryResponse.general_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='generalItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_serving_status_summary', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryResponse.full_serving_status_summary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fullServingStatusSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant_names', full_name='tecton_proto.metadataservice.GetFeatureServiceSummaryResponse.variant_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='variantNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=2026,
)


_GETVIRTUALDATASOURCESUMMARYREQUEST = _descriptor.Descriptor(
  name='GetVirtualDataSourceSummaryRequest',
  full_name='tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2028,
  serialized_end=2130,
)


_GETVIRTUALDATASOURCESUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetVirtualDataSourceSummaryResponse',
  full_name='tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_summary', full_name='tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse.fco_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2132,
  serialized_end=2233,
)


_GETTRANSFORMATIONSUMMARYREQUEST = _descriptor.Descriptor(
  name='GetTransformationSummaryRequest',
  full_name='tecton_proto.metadataservice.GetTransformationSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.GetTransformationSummaryRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2235,
  serialized_end=2334,
)


_GETTRANSFORMATIONSUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetTransformationSummaryResponse',
  full_name='tecton_proto.metadataservice.GetTransformationSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_summary', full_name='tecton_proto.metadataservice.GetTransformationSummaryResponse.fco_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2336,
  serialized_end=2434,
)


_GETENTITYSUMMARYREQUEST = _descriptor.Descriptor(
  name='GetEntitySummaryRequest',
  full_name='tecton_proto.metadataservice.GetEntitySummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.GetEntitySummaryRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2527,
)


_GETENTITYSUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetEntitySummaryResponse',
  full_name='tecton_proto.metadataservice.GetEntitySummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_summary', full_name='tecton_proto.metadataservice.GetEntitySummaryResponse.fco_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2529,
  serialized_end=2619,
)


_GETSERVINGSTATUSREQUEST = _descriptor.Descriptor(
  name='GetServingStatusRequest',
  full_name='tecton_proto.metadataservice.GetServingStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.metadataservice.GetServingStatusRequest.feature_package_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.metadataservice.GetServingStatusRequest.feature_service_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetServingStatusRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_type', full_name='tecton_proto.metadataservice.GetServingStatusRequest.request_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2622,
  serialized_end=2839,
)


_GETSERVINGSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetServingStatusResponse',
  full_name='tecton_proto.metadataservice.GetServingStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serving_status_summary', full_name='tecton_proto.metadataservice.GetServingStatusResponse.serving_status_summary', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingStatusSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2841,
  serialized_end=2962,
)


_GETALLFEATUREFRESHNESSREQUEST = _descriptor.Descriptor(
  name='GetAllFeatureFreshnessRequest',
  full_name='tecton_proto.metadataservice.GetAllFeatureFreshnessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllFeatureFreshnessRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2964,
  serialized_end=3025,
)


_GETALLFEATUREFRESHNESSRESPONSE = _descriptor.Descriptor(
  name='GetAllFeatureFreshnessResponse',
  full_name='tecton_proto.metadataservice.GetAllFeatureFreshnessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='freshness_statuses', full_name='tecton_proto.metadataservice.GetAllFeatureFreshnessResponse.freshness_statuses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='freshnessStatuses', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3027,
  serialized_end=3142,
)


_GETFEATUREFRESHNESSREQUEST = _descriptor.Descriptor(
  name='GetFeatureFreshnessRequest',
  full_name='tecton_proto.metadataservice.GetFeatureFreshnessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.GetFeatureFreshnessRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3144,
  serialized_end=3238,
)


_GETFEATUREFRESHNESSRESPONSE = _descriptor.Descriptor(
  name='GetFeatureFreshnessResponse',
  full_name='tecton_proto.metadataservice.GetFeatureFreshnessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='freshness_status', full_name='tecton_proto.metadataservice.GetFeatureFreshnessResponse.freshness_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='freshnessStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3240,
  serialized_end=3348,
)


_GETMATERIALIZATIONSTATUSREQUEST = _descriptor.Descriptor(
  name='GetMaterializationStatusRequest',
  full_name='tecton_proto.metadataservice.GetMaterializationStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.metadataservice.GetMaterializationStatusRequest.feature_package_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3350,
  serialized_end=3454,
)


_GETMATERIALIZATIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetMaterializationStatusResponse',
  full_name='tecton_proto.metadataservice.GetMaterializationStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_status', full_name='tecton_proto.metadataservice.GetMaterializationStatusResponse.materialization_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3457,
  serialized_end=3588,
)


_GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST = _descriptor.Descriptor(
  name='GetAllMaterializationStatusInLiveWorkspacesRequest',
  full_name='tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cut_off_days', full_name='tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest.cut_off_days', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cutOffDays', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3590,
  serialized_end=3676,
)


_FEATUREVIEWMATERIALIZATIONSTATUS = _descriptor.Descriptor(
  name='FeatureViewMaterializationStatus',
  full_name='tecton_proto.metadataservice.FeatureViewMaterializationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.FeatureViewMaterializationStatus.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_status', full_name='tecton_proto.metadataservice.FeatureViewMaterializationStatus.materialization_status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3679,
  serialized_end=3876,
)


_GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE = _descriptor.Descriptor(
  name='GetAllMaterializationStatusInLiveWorkspacesResponse',
  full_name='tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_materialization_status', full_name='tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse.feature_view_materialization_status', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewMaterializationStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3879,
  serialized_end=4076,
)


_FORCERETRYMATERIALIZATIONTASKREQUEST = _descriptor.Descriptor(
  name='ForceRetryMaterializationTaskRequest',
  full_name='tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_task_id', full_name='tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest.materialization_task_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationTaskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4078,
  serialized_end=4197,
)


_FORCERETRYMATERIALIZATIONTASKRESPONSE = _descriptor.Descriptor(
  name='ForceRetryMaterializationTaskResponse',
  full_name='tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse.error_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4199,
  serialized_end=4275,
)


_GETFCOSREQUEST = _descriptor.Descriptor(
  name='GetFcosRequest',
  full_name='tecton_proto.metadataservice.GetFcosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetFcosRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4277,
  serialized_end=4323,
)


_GETFCOSRESPONSE = _descriptor.Descriptor(
  name='GetFcosResponse',
  full_name='tecton_proto.metadataservice.GetFcosResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetFcosResponse.fco_container', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4325,
  serialized_end=4412,
)


_GETFEATUREVIEWREQUEST = _descriptor.Descriptor(
  name='GetFeatureViewRequest',
  full_name='tecton_proto.metadataservice.GetFeatureViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_specifier', full_name='tecton_proto.metadataservice.GetFeatureViewRequest.version_specifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='versionSpecifier', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetFeatureViewRequest.workspace', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.metadataservice.GetFeatureViewRequest.id', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.GetFeatureViewRequest.disable_legacy_response', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4415,
  serialized_end=4610,
)


_GETFEATUREVIEWRESPONSE = _descriptor.Descriptor(
  name='GetFeatureViewResponse',
  full_name='tecton_proto.metadataservice.GetFeatureViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.metadataservice.GetFeatureViewResponse.feature_view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetFeatureViewResponse.fco_container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4613,
  serialized_end=4778,
)


_GETFEATUREVIEWSUMMARYREQUEST = _descriptor.Descriptor(
  name='GetFeatureViewSummaryRequest',
  full_name='tecton_proto.metadataservice.GetFeatureViewSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.GetFeatureViewSummaryRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4780,
  serialized_end=4876,
)


_GETFEATUREVIEWSUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetFeatureViewSummaryResponse',
  full_name='tecton_proto.metadataservice.GetFeatureViewSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_summary', full_name='tecton_proto.metadataservice.GetFeatureViewSummaryResponse.fco_summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4878,
  serialized_end=4973,
)


_QUERYFEATUREVIEWSREQUEST = _descriptor.Descriptor(
  name='QueryFeatureViewsRequest',
  full_name='tecton_proto.metadataservice.QueryFeatureViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.metadataservice.QueryFeatureViewsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.QueryFeatureViewsRequest.workspace', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.QueryFeatureViewsRequest.disable_legacy_response', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4976,
  serialized_end=5108,
)


_QUERYFEATUREVIEWSRESPONSE = _descriptor.Descriptor(
  name='QueryFeatureViewsResponse',
  full_name='tecton_proto.metadataservice.QueryFeatureViewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_views', full_name='tecton_proto.metadataservice.QueryFeatureViewsResponse.feature_views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='featureViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.QueryFeatureViewsResponse.fco_container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5111,
  serialized_end=5281,
)


_GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE = _descriptor.Descriptor(
  name='GetMaterializingFeatureViewsInLiveWorkspacesResponse',
  full_name='tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_views', full_name='tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse.feature_views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5283,
  serialized_end=5406,
)


_GETVIRTUALDATASOURCEREQUEST = _descriptor.Descriptor(
  name='GetVirtualDataSourceRequest',
  full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source_id', full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest.virtual_data_source_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest.disable_legacy_response', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier_type', full_name='tecton_proto.metadataservice.GetVirtualDataSourceRequest.identifier_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5409,
  serialized_end=5645,
)


_GETVIRTUALDATASOURCERESPONSE = _descriptor.Descriptor(
  name='GetVirtualDataSourceResponse',
  full_name='tecton_proto.metadataservice.GetVirtualDataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source', full_name='tecton_proto.metadataservice.GetVirtualDataSourceResponse.virtual_data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSource', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetVirtualDataSourceResponse.fco_container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5648,
  serialized_end=5834,
)


_GETALLVIRTUALDATASOURCESREQUEST = _descriptor.Descriptor(
  name='GetAllVirtualDataSourcesRequest',
  full_name='tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5836,
  serialized_end=5899,
)


_GETALLVIRTUALDATASOURCESRESPONSE = _descriptor.Descriptor(
  name='GetAllVirtualDataSourcesResponse',
  full_name='tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse.virtual_data_sources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5901,
  serialized_end=6023,
)


_GETENTITYREQUEST = _descriptor.Descriptor(
  name='GetEntityRequest',
  full_name='tecton_proto.metadataservice.GetEntityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_id', full_name='tecton_proto.metadataservice.GetEntityRequest.entity_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.metadataservice.GetEntityRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetEntityRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.GetEntityRequest.disable_legacy_response', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier_type', full_name='tecton_proto.metadataservice.GetEntityRequest.identifier_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6026,
  serialized_end=6227,
)


_GETENTITYRESPONSE = _descriptor.Descriptor(
  name='GetEntityResponse',
  full_name='tecton_proto.metadataservice.GetEntityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity', full_name='tecton_proto.metadataservice.GetEntityResponse.entity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetEntityResponse.fco_container', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6230,
  serialized_end=6370,
)


_GETALLENTITIESREQUEST = _descriptor.Descriptor(
  name='GetAllEntitiesRequest',
  full_name='tecton_proto.metadataservice.GetAllEntitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllEntitiesRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6372,
  serialized_end=6425,
)


_GETALLENTITIESRESPONSE = _descriptor.Descriptor(
  name='GetAllEntitiesResponse',
  full_name='tecton_proto.metadataservice.GetAllEntitiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='tecton_proto.metadataservice.GetAllEntitiesResponse.entities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6427,
  serialized_end=6506,
)


_GETTRANSFORMATIONREQUEST = _descriptor.Descriptor(
  name='GetTransformationRequest',
  full_name='tecton_proto.metadataservice.GetTransformationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_id', full_name='tecton_proto.metadataservice.GetTransformationRequest.transformation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.metadataservice.GetTransformationRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetTransformationRequest.workspace', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_legacy_response', full_name='tecton_proto.metadataservice.GetTransformationRequest.disable_legacy_response', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='disableLegacyResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier_type', full_name='tecton_proto.metadataservice.GetTransformationRequest.identifier_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6509,
  serialized_end=6734,
)


_GETTRANSFORMATIONRESPONSE = _descriptor.Descriptor(
  name='GetTransformationResponse',
  full_name='tecton_proto.metadataservice.GetTransformationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_transformation', full_name='tecton_proto.metadataservice.GetTransformationResponse.new_transformation', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newTransformation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_container', full_name='tecton_proto.metadataservice.GetTransformationResponse.fco_container', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoContainer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6737,
  serialized_end=6925,
)


_GETALLTRANSFORMATIONSREQUEST = _descriptor.Descriptor(
  name='GetAllTransformationsRequest',
  full_name='tecton_proto.metadataservice.GetAllTransformationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllTransformationsRequest.workspace', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6927,
  serialized_end=6987,
)


_GETALLTRANSFORMATIONSRESPONSE = _descriptor.Descriptor(
  name='GetAllTransformationsResponse',
  full_name='tecton_proto.metadataservice.GetAllTransformationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_transformations', full_name='tecton_proto.metadataservice.GetAllTransformationsResponse.new_transformations', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newTransformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6989,
  serialized_end=7113,
)


_FINDFCOWORKSPACEREQUEST = _descriptor.Descriptor(
  name='FindFcoWorkspaceRequest',
  full_name='tecton_proto.metadataservice.FindFcoWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.metadataservice.FindFcoWorkspaceRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7115,
  serialized_end=7181,
)


_FINDFCOWORKSPACERESPONSE = _descriptor.Descriptor(
  name='FindFcoWorkspaceResponse',
  full_name='tecton_proto.metadataservice.FindFcoWorkspaceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.FindFcoWorkspaceResponse.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7183,
  serialized_end=7239,
)


_INGESTCLIENTLOGSREQUEST = _descriptor.Descriptor(
  name='IngestClientLogsRequest',
  full_name='tecton_proto.metadataservice.IngestClientLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdk_method_invocation', full_name='tecton_proto.metadataservice.IngestClientLogsRequest.sdk_method_invocation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sdkMethodInvocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7241,
  serialized_end=7363,
)


_INGESTANALYTICSREQUEST = _descriptor.Descriptor(
  name='IngestAnalyticsRequest',
  full_name='tecton_proto.metadataservice.IngestAnalyticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='tecton_proto.metadataservice.IngestAnalyticsRequest.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.IngestAnalyticsRequest.workspace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7365,
  serialized_end=7483,
)


_NEWSTATEUPDATEREQUEST = _descriptor.Descriptor(
  name='NewStateUpdateRequest',
  full_name='tecton_proto.metadataservice.NewStateUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tecton_proto.metadataservice.NewStateUpdateRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocking_dry_run_mode', full_name='tecton_proto.metadataservice.NewStateUpdateRequest.blocking_dry_run_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='blockingDryRunMode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7486,
  serialized_end=7625,
)


_NEWSTATEUPDATERESPONSE = _descriptor.Descriptor(
  name='NewStateUpdateResponse',
  full_name='tecton_proto.metadataservice.NewStateUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_id', full_name='tecton_proto.metadataservice.NewStateUpdateResponse.state_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_url_for_repo_upload', full_name='tecton_proto.metadataservice.NewStateUpdateResponse.signed_url_for_repo_upload', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signedUrlForRepoUpload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocking_dry_run_mode_response', full_name='tecton_proto.metadataservice.NewStateUpdateResponse.blocking_dry_run_mode_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='blockingDryRunModeResponse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7628,
  serialized_end=7888,
)


_QUERYSTATEUPDATEREQUEST = _descriptor.Descriptor(
  name='QueryStateUpdateRequest',
  full_name='tecton_proto.metadataservice.QueryStateUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_id', full_name='tecton_proto.metadataservice.QueryStateUpdateRequest.state_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.QueryStateUpdateRequest.workspace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7890,
  serialized_end=7997,
)


_QUERYSTATEUPDATERESPONSE = _descriptor.Descriptor(
  name='QueryStateUpdateResponse',
  full_name='tecton_proto.metadataservice.QueryStateUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ready', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.ready', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ready', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='success', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation_result', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.validation_result', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validationResult', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diff_items', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.diff_items', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='diffItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_status_message', full_name='tecton_proto.metadataservice.QueryStateUpdateResponse.latest_status_message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='latestStatusMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8000,
  serialized_end=8289,
)


_APPLYSTATEUPDATEREQUEST = _descriptor.Descriptor(
  name='ApplyStateUpdateRequest',
  full_name='tecton_proto.metadataservice.ApplyStateUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_id', full_name='tecton_proto.metadataservice.ApplyStateUpdateRequest.state_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stateId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='applied_by', full_name='tecton_proto.metadataservice.ApplyStateUpdateRequest.applied_by', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='appliedBy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8291,
  serialized_end=8403,
)


_APPLYSTATEUPDATERESPONSE = _descriptor.Descriptor(
  name='ApplyStateUpdateResponse',
  full_name='tecton_proto.metadataservice.ApplyStateUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8405,
  serialized_end=8431,
)


_GETCONFIGSRESPONSE_KEYVALUESENTRY = _descriptor.Descriptor(
  name='KeyValuesEntry',
  full_name='tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8552,
  serialized_end=8612,
)

_GETCONFIGSRESPONSE = _descriptor.Descriptor(
  name='GetConfigsResponse',
  full_name='tecton_proto.metadataservice.GetConfigsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_values', full_name='tecton_proto.metadataservice.GetConfigsResponse.key_values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='keyValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETCONFIGSRESPONSE_KEYVALUESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8434,
  serialized_end=8612,
)


_GETSTATEUPDATELOGREQUEST = _descriptor.Descriptor(
  name='GetStateUpdateLogRequest',
  full_name='tecton_proto.metadataservice.GetStateUpdateLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='tecton_proto.metadataservice.GetStateUpdateLogRequest.limit', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetStateUpdateLogRequest.workspace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8614,
  serialized_end=8692,
)


_GETSTATEUPDATELOGRESPONSE = _descriptor.Descriptor(
  name='GetStateUpdateLogResponse',
  full_name='tecton_proto.metadataservice.GetStateUpdateLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='tecton_proto.metadataservice.GetStateUpdateLogResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8694,
  serialized_end=8784,
)


_GETRESTOREINFOREQUEST = _descriptor.Descriptor(
  name='GetRestoreInfoRequest',
  full_name='tecton_proto.metadataservice.GetRestoreInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_id', full_name='tecton_proto.metadataservice.GetRestoreInfoRequest.commit_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetRestoreInfoRequest.workspace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8786,
  serialized_end=8868,
)


_GETRESTOREINFORESPONSE = _descriptor.Descriptor(
  name='GetRestoreInfoResponse',
  full_name='tecton_proto.metadataservice.GetRestoreInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_url_for_repo_download', full_name='tecton_proto.metadataservice.GetRestoreInfoResponse.signed_url_for_repo_download', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signedUrlForRepoDownload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_id', full_name='tecton_proto.metadataservice.GetRestoreInfoResponse.commit_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_version', full_name='tecton_proto.metadataservice.GetRestoreInfoResponse.sdk_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sdkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8871,
  serialized_end=9021,
)


_CREATEWORKSPACEREQUEST = _descriptor.Descriptor(
  name='CreateWorkspaceRequest',
  full_name='tecton_proto.metadataservice.CreateWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.metadataservice.CreateWorkspaceRequest.workspace_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='tecton_proto.metadataservice.CreateWorkspaceRequest.capabilities', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='capabilities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9024,
  serialized_end=9171,
)


_DELETEWORKSPACEREQUEST = _descriptor.Descriptor(
  name='DeleteWorkspaceRequest',
  full_name='tecton_proto.metadataservice.DeleteWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.DeleteWorkspaceRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9173,
  serialized_end=9227,
)


_CREATEAPIKEYREQUEST = _descriptor.Descriptor(
  name='CreateApiKeyRequest',
  full_name='tecton_proto.metadataservice.CreateApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='tecton_proto.metadataservice.CreateApiKeyRequest.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='tecton_proto.metadataservice.CreateApiKeyRequest.is_admin', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9229,
  serialized_end=9311,
)


_CREATEAPIKEYRESPONSE = _descriptor.Descriptor(
  name='CreateApiKeyResponse',
  full_name='tecton_proto.metadataservice.CreateApiKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.metadataservice.CreateApiKeyResponse.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9313,
  serialized_end=9353,
)


_DELETEAPIKEYREQUEST = _descriptor.Descriptor(
  name='DeleteApiKeyRequest',
  full_name='tecton_proto.metadataservice.DeleteApiKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.metadataservice.DeleteApiKeyRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9355,
  serialized_end=9417,
)


_LISTAPIKEYSREQUEST = _descriptor.Descriptor(
  name='ListApiKeysRequest',
  full_name='tecton_proto.metadataservice.ListApiKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_archived', full_name='tecton_proto.metadataservice.ListApiKeysRequest.include_archived', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeArchived', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9419,
  serialized_end=9482,
)


_LISTAPIKEYSRESPONSE = _descriptor.Descriptor(
  name='ListApiKeysResponse',
  full_name='tecton_proto.metadataservice.ListApiKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_keys', full_name='tecton_proto.metadataservice.ListApiKeysResponse.api_keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='apiKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9484,
  serialized_end=9565,
)


_LISTWORKSPACESREQUEST = _descriptor.Descriptor(
  name='ListWorkspacesRequest',
  full_name='tecton_proto.metadataservice.ListWorkspacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9567,
  serialized_end=9590,
)


_LISTWORKSPACESRESPONSE = _descriptor.Descriptor(
  name='ListWorkspacesResponse',
  full_name='tecton_proto.metadataservice.ListWorkspacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaces', full_name='tecton_proto.metadataservice.ListWorkspacesResponse.workspaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaces', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9592,
  serialized_end=9678,
)


_GETWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetWorkspaceRequest',
  full_name='tecton_proto.metadataservice.GetWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.metadataservice.GetWorkspaceRequest.workspace_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9680,
  serialized_end=9740,
)


_GETWORKSPACERESPONSE = _descriptor.Descriptor(
  name='GetWorkspaceResponse',
  full_name='tecton_proto.metadataservice.GetWorkspaceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetWorkspaceResponse.workspace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9742,
  serialized_end=9824,
)


_CREATESAVEDFEATUREDATAFRAMEREQUEST = _descriptor.Descriptor(
  name='CreateSavedFeatureDataFrameRequest',
  full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.workspace', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.feature_package_id', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.feature_service_id', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key_column_names', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.join_key_column_names', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyColumnNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_column_name', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.timestamp_column_name', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.schema', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=9827,
  serialized_end=10230,
)


_CREATESAVEDFEATUREDATAFRAMERESPONSE = _descriptor.Descriptor(
  name='CreateSavedFeatureDataFrameResponse',
  full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe', full_name='tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse.saved_feature_dataframe', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframe', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10233,
  serialized_end=10368,
)


_ARCHIVESAVEDFEATUREDATAFRAMEREQUEST = _descriptor.Descriptor(
  name='ArchiveSavedFeatureDataFrameRequest',
  full_name='tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe_id', full_name='tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest.saved_feature_dataframe_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10370,
  serialized_end=10493,
)


_ARCHIVESAVEDFEATUREDATAFRAMERESPONSE = _descriptor.Descriptor(
  name='ArchiveSavedFeatureDataFrameResponse',
  full_name='tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10495,
  serialized_end=10533,
)


_GETSAVEDFEATUREDATAFRAMEREQUEST = _descriptor.Descriptor(
  name='GetSavedFeatureDataFrameRequest',
  full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe_name', full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest.saved_feature_dataframe_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframeName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe_id', full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest.saved_feature_dataframe_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='reference', full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest.reference',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=10536,
  serialized_end=10767,
)


_GETCLUSTERADMININFORESPONSE = _descriptor.Descriptor(
  name='GetClusterAdminInfoResponse',
  full_name='tecton_proto.metadataservice.GetClusterAdminInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='caller_is_admin', full_name='tecton_proto.metadataservice.GetClusterAdminInfoResponse.caller_is_admin', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='callerIsAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='tecton_proto.metadataservice.GetClusterAdminInfoResponse.users', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='users', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admins', full_name='tecton_proto.metadataservice.GetClusterAdminInfoResponse.admins', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='admins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10770,
  serialized_end=10935,
)


_CREATECLUSTERUSERREQUEST = _descriptor.Descriptor(
  name='CreateClusterUserRequest',
  full_name='tecton_proto.metadataservice.CreateClusterUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_email', full_name='tecton_proto.metadataservice.CreateClusterUserRequest.login_email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='loginEmail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10937,
  serialized_end=10996,
)


_CREATECLUSTERUSERRESPONSE = _descriptor.Descriptor(
  name='CreateClusterUserResponse',
  full_name='tecton_proto.metadataservice.CreateClusterUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.metadataservice.CreateClusterUserResponse.error_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10998,
  serialized_end=11062,
)


_DELETECLUSTERUSERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterUserRequest',
  full_name='tecton_proto.metadataservice.DeleteClusterUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='okta_id', full_name='tecton_proto.metadataservice.DeleteClusterUserRequest.okta_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oktaId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11064,
  serialized_end=11115,
)


_DELETECLUSTERUSERRESPONSE = _descriptor.Descriptor(
  name='DeleteClusterUserResponse',
  full_name='tecton_proto.metadataservice.DeleteClusterUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.metadataservice.DeleteClusterUserResponse.error_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11117,
  serialized_end=11181,
)


_CLUSTERUSERACTIONREQUEST = _descriptor.Descriptor(
  name='ClusterUserActionRequest',
  full_name='tecton_proto.metadataservice.ClusterUserActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='okta_id', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.okta_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oktaId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resend_activation_email', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.resend_activation_email', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resendActivationEmail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlock_user', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.unlock_user', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='unlockUser', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grant_admin', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.grant_admin', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='grantAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revoke_admin', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.revoke_admin', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='revokeAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='tecton_proto.metadataservice.ClusterUserActionRequest.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=11184,
  serialized_end=11410,
)


_CLUSTERUSERACTIONRESPONSE = _descriptor.Descriptor(
  name='ClusterUserActionResponse',
  full_name='tecton_proto.metadataservice.ClusterUserActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.metadataservice.ClusterUserActionResponse.error_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11412,
  serialized_end=11476,
)


_GETSAVEDFEATUREDATAFRAMERESPONSE = _descriptor.Descriptor(
  name='GetSavedFeatureDataFrameResponse',
  full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe', full_name='tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse.saved_feature_dataframe', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframe', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11479,
  serialized_end=11611,
)


_GETALLSAVEDFEATUREDATAFRAMESREQUEST = _descriptor.Descriptor(
  name='GetAllSavedFeatureDataFramesRequest',
  full_name='tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest.workspace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11613,
  serialized_end=11680,
)


_GETALLSAVEDFEATUREDATAFRAMESRESPONSE = _descriptor.Descriptor(
  name='GetAllSavedFeatureDataFramesResponse',
  full_name='tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframes', full_name='tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse.saved_feature_dataframes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11683,
  serialized_end=11821,
)


_INGESTDATAFRAMEREQUEST = _descriptor.Descriptor(
  name='IngestDataframeRequest',
  full_name='tecton_proto.metadataservice.IngestDataframeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_definition_id', full_name='tecton_proto.metadataservice.IngestDataframeRequest.feature_definition_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureDefinitionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='df_path', full_name='tecton_proto.metadataservice.IngestDataframeRequest.df_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dfPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.metadataservice.IngestDataframeRequest.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11824,
  serialized_end=11980,
)


_INGESTDATAFRAMERESPONSE = _descriptor.Descriptor(
  name='IngestDataframeResponse',
  full_name='tecton_proto.metadataservice.IngestDataframeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11982,
  serialized_end=12007,
)


_GETNEWINGESTDATAFRAMEINFOREQUEST = _descriptor.Descriptor(
  name='GetNewIngestDataframeInfoRequest',
  full_name='tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_definition_id', full_name='tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest.feature_definition_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureDefinitionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12009,
  serialized_end=12120,
)


_GETNEWINGESTDATAFRAMEINFORESPONSE = _descriptor.Descriptor(
  name='GetNewIngestDataframeInfoResponse',
  full_name='tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='df_path', full_name='tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse.df_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dfPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_url_for_df_upload', full_name='tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse.signed_url_for_df_upload', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signedUrlForDfUpload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12122,
  serialized_end=12238,
)


_GETUSERDEPLOYMENTSETTINGSRESPONSE = _descriptor.Descriptor(
  name='GetUserDeploymentSettingsResponse',
  full_name='tecton_proto.metadataservice.GetUserDeploymentSettingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_deployment_settings', full_name='tecton_proto.metadataservice.GetUserDeploymentSettingsResponse.user_deployment_settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userDeploymentSettings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12241,
  serialized_end=12377,
)


_UPDATEUSERDEPLOYMENTSETTINGSREQUEST = _descriptor.Descriptor(
  name='UpdateUserDeploymentSettingsRequest',
  full_name='tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_deployment_settings', full_name='tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest.user_deployment_settings', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userDeploymentSettings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12380,
  serialized_end=12518,
)


_UPDATEUSERDEPLOYMENTSETTINGSRESPONSE = _descriptor.Descriptor(
  name='UpdateUserDeploymentSettingsResponse',
  full_name='tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='success', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse.error_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12520,
  serialized_end=12621,
)


_GETINTERNALSPARKCLUSTERSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetInternalSparkClusterStatusResponse',
  full_name='tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETINTERNALSPARKCLUSTERSTATUSRESPONSE_INTERNALSPARKCLUSTERSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12624,
  serialized_end=13035,
)


_GETDELETEENTITIESINFOREQUEST = _descriptor.Descriptor(
  name='GetDeleteEntitiesInfoRequest',
  full_name='tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_definition_id', full_name='tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest.feature_definition_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureDefinitionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13037,
  serialized_end=13144,
)


_GETDELETEENTITIESINFORESPONSE = _descriptor.Descriptor(
  name='GetDeleteEntitiesInfoResponse',
  full_name='tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='df_path', full_name='tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse.df_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dfPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_url_for_df_upload', full_name='tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse.signed_url_for_df_upload', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signedUrlForDfUpload', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13146,
  serialized_end=13258,
)


_DELETEENTITIESREQUEST = _descriptor.Descriptor(
  name='DeleteEntitiesRequest',
  full_name='tecton_proto.metadataservice.DeleteEntitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_locator', full_name='tecton_proto.metadataservice.DeleteEntitiesRequest.fco_locator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_join_keys_path', full_name='tecton_proto.metadataservice.DeleteEntitiesRequest.online_join_keys_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineJoinKeysPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_join_keys_path', full_name='tecton_proto.metadataservice.DeleteEntitiesRequest.offline_join_keys_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineJoinKeysPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online', full_name='tecton_proto.metadataservice.DeleteEntitiesRequest.online', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='online', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline', full_name='tecton_proto.metadataservice.DeleteEntitiesRequest.offline', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13261,
  serialized_end=13504,
)


_DELETEENTITIESRESPONSE = _descriptor.Descriptor(
  name='DeleteEntitiesResponse',
  full_name='tecton_proto.metadataservice.DeleteEntitiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13506,
  serialized_end=13530,
)

_GETFEATURESERVICEREQUEST.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETFEATURESERVICERESPONSE.fields_by_name['feature_service'].message_type = tecton__proto_dot_data_dot_feature__service__pb2._FEATURESERVICE
_GETFEATURESERVICERESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETALLFEATURESERVICESRESPONSE.fields_by_name['feature_services'].message_type = tecton__proto_dot_data_dot_feature__service__pb2._FEATURESERVICE
_GETFEATURESERVICESUMMARYREQUEST.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETFEATURESERVICESUMMARYREQUEST.oneofs_by_name['locator'].fields.append(
  _GETFEATURESERVICESUMMARYREQUEST.fields_by_name['feature_service_id'])
_GETFEATURESERVICESUMMARYREQUEST.fields_by_name['feature_service_id'].containing_oneof = _GETFEATURESERVICESUMMARYREQUEST.oneofs_by_name['locator']
_GETFEATURESERVICESUMMARYREQUEST.oneofs_by_name['locator'].fields.append(
  _GETFEATURESERVICESUMMARYREQUEST.fields_by_name['feature_service_name'])
_GETFEATURESERVICESUMMARYREQUEST.fields_by_name['feature_service_name'].containing_oneof = _GETFEATURESERVICESUMMARYREQUEST.oneofs_by_name['locator']
_GETFEATURESERVICESUMMARYRESPONSE.fields_by_name['general_items'].message_type = tecton__proto_dot_data_dot_summary__pb2._SUMMARYITEM
_GETFEATURESERVICESUMMARYRESPONSE.fields_by_name['full_serving_status_summary'].message_type = tecton__proto_dot_data_dot_serving__status__pb2._FULLFEATURESERVICESERVINGSUMMARY
_GETVIRTUALDATASOURCESUMMARYREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_GETVIRTUALDATASOURCESUMMARYRESPONSE.fields_by_name['fco_summary'].message_type = tecton__proto_dot_data_dot_summary__pb2._FCOSUMMARY
_GETTRANSFORMATIONSUMMARYREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_GETTRANSFORMATIONSUMMARYRESPONSE.fields_by_name['fco_summary'].message_type = tecton__proto_dot_data_dot_summary__pb2._FCOSUMMARY
_GETENTITYSUMMARYREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_GETENTITYSUMMARYRESPONSE.fields_by_name['fco_summary'].message_type = tecton__proto_dot_data_dot_summary__pb2._FCOSUMMARY
_GETSERVINGSTATUSREQUEST.fields_by_name['feature_package_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETSERVINGSTATUSREQUEST.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETSERVINGSTATUSREQUEST.oneofs_by_name['request_type'].fields.append(
  _GETSERVINGSTATUSREQUEST.fields_by_name['feature_package_id'])
_GETSERVINGSTATUSREQUEST.fields_by_name['feature_package_id'].containing_oneof = _GETSERVINGSTATUSREQUEST.oneofs_by_name['request_type']
_GETSERVINGSTATUSREQUEST.oneofs_by_name['request_type'].fields.append(
  _GETSERVINGSTATUSREQUEST.fields_by_name['feature_service_id'])
_GETSERVINGSTATUSREQUEST.fields_by_name['feature_service_id'].containing_oneof = _GETSERVINGSTATUSREQUEST.oneofs_by_name['request_type']
_GETSERVINGSTATUSRESPONSE.fields_by_name['serving_status_summary'].message_type = tecton__proto_dot_data_dot_serving__status__pb2._SERVINGSTATUSSUMMARY
_GETALLFEATUREFRESHNESSRESPONSE.fields_by_name['freshness_statuses'].message_type = tecton__proto_dot_data_dot_freshness__status__pb2._FRESHNESSSTATUS
_GETFEATUREFRESHNESSREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_GETFEATUREFRESHNESSRESPONSE.fields_by_name['freshness_status'].message_type = tecton__proto_dot_data_dot_freshness__status__pb2._FRESHNESSSTATUS
_GETMATERIALIZATIONSTATUSREQUEST.fields_by_name['feature_package_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETMATERIALIZATIONSTATUSRESPONSE.fields_by_name['materialization_status'].message_type = tecton__proto_dot_data_dot_materialization__status__pb2._MATERIALIZATIONSTATUS
_FEATUREVIEWMATERIALIZATIONSTATUS.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_FEATUREVIEWMATERIALIZATIONSTATUS.fields_by_name['materialization_status'].message_type = tecton__proto_dot_data_dot_materialization__status__pb2._MATERIALIZATIONSTATUS
_GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE.fields_by_name['feature_view_materialization_status'].message_type = _FEATUREVIEWMATERIALIZATIONSTATUS
_FORCERETRYMATERIALIZATIONTASKREQUEST.fields_by_name['materialization_task_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETFCOSRESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETFEATUREVIEWREQUEST.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETFEATUREVIEWRESPONSE.fields_by_name['feature_view'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._FEATUREVIEW
_GETFEATUREVIEWRESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETFEATUREVIEWSUMMARYREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_GETFEATUREVIEWSUMMARYRESPONSE.fields_by_name['fco_summary'].message_type = tecton__proto_dot_data_dot_summary__pb2._FCOSUMMARY
_QUERYFEATUREVIEWSRESPONSE.fields_by_name['feature_views'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._FEATUREVIEW
_QUERYFEATUREVIEWSRESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE.fields_by_name['feature_views'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._FEATUREVIEW
_GETVIRTUALDATASOURCEREQUEST.fields_by_name['virtual_data_source_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETVIRTUALDATASOURCEREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETVIRTUALDATASOURCEREQUEST.fields_by_name['virtual_data_source_id'])
_GETVIRTUALDATASOURCEREQUEST.fields_by_name['virtual_data_source_id'].containing_oneof = _GETVIRTUALDATASOURCEREQUEST.oneofs_by_name['identifier_type']
_GETVIRTUALDATASOURCEREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETVIRTUALDATASOURCEREQUEST.fields_by_name['name'])
_GETVIRTUALDATASOURCEREQUEST.fields_by_name['name'].containing_oneof = _GETVIRTUALDATASOURCEREQUEST.oneofs_by_name['identifier_type']
_GETVIRTUALDATASOURCERESPONSE.fields_by_name['virtual_data_source'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_GETVIRTUALDATASOURCERESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETALLVIRTUALDATASOURCESRESPONSE.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_GETENTITYREQUEST.fields_by_name['entity_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETENTITYREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETENTITYREQUEST.fields_by_name['entity_id'])
_GETENTITYREQUEST.fields_by_name['entity_id'].containing_oneof = _GETENTITYREQUEST.oneofs_by_name['identifier_type']
_GETENTITYREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETENTITYREQUEST.fields_by_name['name'])
_GETENTITYREQUEST.fields_by_name['name'].containing_oneof = _GETENTITYREQUEST.oneofs_by_name['identifier_type']
_GETENTITYRESPONSE.fields_by_name['entity'].message_type = tecton__proto_dot_data_dot_entity__pb2._ENTITY
_GETENTITYRESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETALLENTITIESRESPONSE.fields_by_name['entities'].message_type = tecton__proto_dot_data_dot_entity__pb2._ENTITY
_GETTRANSFORMATIONREQUEST.fields_by_name['transformation_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETTRANSFORMATIONREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETTRANSFORMATIONREQUEST.fields_by_name['transformation_id'])
_GETTRANSFORMATIONREQUEST.fields_by_name['transformation_id'].containing_oneof = _GETTRANSFORMATIONREQUEST.oneofs_by_name['identifier_type']
_GETTRANSFORMATIONREQUEST.oneofs_by_name['identifier_type'].fields.append(
  _GETTRANSFORMATIONREQUEST.fields_by_name['name'])
_GETTRANSFORMATIONREQUEST.fields_by_name['name'].containing_oneof = _GETTRANSFORMATIONREQUEST.oneofs_by_name['identifier_type']
_GETTRANSFORMATIONRESPONSE.fields_by_name['new_transformation'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_GETTRANSFORMATIONRESPONSE.fields_by_name['fco_container'].message_type = tecton__proto_dot_data_dot_fco__pb2._FCOCONTAINER
_GETALLTRANSFORMATIONSRESPONSE.fields_by_name['new_transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_FINDFCOWORKSPACEREQUEST.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_INGESTCLIENTLOGSREQUEST.fields_by_name['sdk_method_invocation'].message_type = tecton__proto_dot_amplitude_dot_client__logging__pb2._SDKMETHODINVOCATION
_INGESTANALYTICSREQUEST.fields_by_name['events'].message_type = tecton__proto_dot_amplitude_dot_amplitude__pb2._AMPLITUDEEVENT
_NEWSTATEUPDATEREQUEST.fields_by_name['request'].message_type = tecton__proto_dot_data_dot_state__update__pb2._STATEUPDATEREQUEST
_NEWSTATEUPDATERESPONSE.fields_by_name['state_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_NEWSTATEUPDATERESPONSE.fields_by_name['blocking_dry_run_mode_response'].message_type = _QUERYSTATEUPDATERESPONSE
_QUERYSTATEUPDATEREQUEST.fields_by_name['state_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_QUERYSTATEUPDATERESPONSE.fields_by_name['validation_result'].message_type = tecton__proto_dot_data_dot_state__update__pb2._VALIDATIONRESULT
_QUERYSTATEUPDATERESPONSE.fields_by_name['diff_items'].message_type = tecton__proto_dot_data_dot_state__update__pb2._FCODIFF
_APPLYSTATEUPDATEREQUEST.fields_by_name['state_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETCONFIGSRESPONSE_KEYVALUESENTRY.containing_type = _GETCONFIGSRESPONSE
_GETCONFIGSRESPONSE.fields_by_name['key_values'].message_type = _GETCONFIGSRESPONSE_KEYVALUESENTRY
_GETSTATEUPDATELOGRESPONSE.fields_by_name['entries'].message_type = tecton__proto_dot_data_dot_state__update__pb2._STATEUPDATEENTRY
_CREATEWORKSPACEREQUEST.fields_by_name['capabilities'].message_type = tecton__proto_dot_data_dot_workspace__pb2._WORKSPACECAPABILITIES
_DELETEAPIKEYREQUEST.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_LISTAPIKEYSRESPONSE.fields_by_name['api_keys'].message_type = tecton__proto_dot_data_dot_tecton__api__key__pb2._TECTONAPIKEY
_LISTWORKSPACESRESPONSE.fields_by_name['workspaces'].message_type = tecton__proto_dot_data_dot_workspace__pb2._WORKSPACE
_GETWORKSPACERESPONSE.fields_by_name['workspace'].message_type = tecton__proto_dot_data_dot_workspace__pb2._WORKSPACE
_CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_package_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_CREATESAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['source'].fields.append(
  _CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_package_id'])
_CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_package_id'].containing_oneof = _CREATESAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['source']
_CREATESAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['source'].fields.append(
  _CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_service_id'])
_CREATESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['feature_service_id'].containing_oneof = _CREATESAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['source']
_CREATESAVEDFEATUREDATAFRAMERESPONSE.fields_by_name['saved_feature_dataframe'].message_type = tecton__proto_dot_data_dot_saved__feature__data__frame__pb2._SAVEDFEATUREDATAFRAME
_ARCHIVESAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETSAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETSAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['reference'].fields.append(
  _GETSAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_name'])
_GETSAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_name'].containing_oneof = _GETSAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['reference']
_GETSAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['reference'].fields.append(
  _GETSAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_id'])
_GETSAVEDFEATUREDATAFRAMEREQUEST.fields_by_name['saved_feature_dataframe_id'].containing_oneof = _GETSAVEDFEATUREDATAFRAMEREQUEST.oneofs_by_name['reference']
_GETCLUSTERADMININFORESPONSE.fields_by_name['users'].message_type = tecton__proto_dot_data_dot_user__pb2._USER
_GETCLUSTERADMININFORESPONSE.fields_by_name['admins'].message_type = tecton__proto_dot_data_dot_user__pb2._USER
_CLUSTERUSERACTIONREQUEST.oneofs_by_name['action'].fields.append(
  _CLUSTERUSERACTIONREQUEST.fields_by_name['resend_activation_email'])
_CLUSTERUSERACTIONREQUEST.fields_by_name['resend_activation_email'].containing_oneof = _CLUSTERUSERACTIONREQUEST.oneofs_by_name['action']
_CLUSTERUSERACTIONREQUEST.oneofs_by_name['action'].fields.append(
  _CLUSTERUSERACTIONREQUEST.fields_by_name['unlock_user'])
_CLUSTERUSERACTIONREQUEST.fields_by_name['unlock_user'].containing_oneof = _CLUSTERUSERACTIONREQUEST.oneofs_by_name['action']
_CLUSTERUSERACTIONREQUEST.oneofs_by_name['action'].fields.append(
  _CLUSTERUSERACTIONREQUEST.fields_by_name['grant_admin'])
_CLUSTERUSERACTIONREQUEST.fields_by_name['grant_admin'].containing_oneof = _CLUSTERUSERACTIONREQUEST.oneofs_by_name['action']
_CLUSTERUSERACTIONREQUEST.oneofs_by_name['action'].fields.append(
  _CLUSTERUSERACTIONREQUEST.fields_by_name['revoke_admin'])
_CLUSTERUSERACTIONREQUEST.fields_by_name['revoke_admin'].containing_oneof = _CLUSTERUSERACTIONREQUEST.oneofs_by_name['action']
_GETSAVEDFEATUREDATAFRAMERESPONSE.fields_by_name['saved_feature_dataframe'].message_type = tecton__proto_dot_data_dot_saved__feature__data__frame__pb2._SAVEDFEATUREDATAFRAME
_GETALLSAVEDFEATUREDATAFRAMESRESPONSE.fields_by_name['saved_feature_dataframes'].message_type = tecton__proto_dot_data_dot_saved__feature__data__frame__pb2._SAVEDFEATUREDATAFRAME
_INGESTDATAFRAMEREQUEST.fields_by_name['feature_definition_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETNEWINGESTDATAFRAMEINFOREQUEST.fields_by_name['feature_definition_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GETUSERDEPLOYMENTSETTINGSRESPONSE.fields_by_name['user_deployment_settings'].message_type = tecton__proto_dot_data_dot_user__deployment__settings__pb2._USERDEPLOYMENTSETTINGS
_UPDATEUSERDEPLOYMENTSETTINGSREQUEST.fields_by_name['user_deployment_settings'].message_type = tecton__proto_dot_data_dot_user__deployment__settings__pb2._USERDEPLOYMENTSETTINGS
_GETINTERNALSPARKCLUSTERSTATUSRESPONSE.fields_by_name['status'].enum_type = _GETINTERNALSPARKCLUSTERSTATUSRESPONSE_INTERNALSPARKCLUSTERSTATUS
_GETINTERNALSPARKCLUSTERSTATUSRESPONSE_INTERNALSPARKCLUSTERSTATUS.containing_type = _GETINTERNALSPARKCLUSTERSTATUSRESPONSE
_GETDELETEENTITIESINFOREQUEST.fields_by_name['feature_definition_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_DELETEENTITIESREQUEST.fields_by_name['fco_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
DESCRIPTOR.message_types_by_name['GetFeatureServiceRequest'] = _GETFEATURESERVICEREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureServiceResponse'] = _GETFEATURESERVICERESPONSE
DESCRIPTOR.message_types_by_name['GetAllFeatureServicesRequest'] = _GETALLFEATURESERVICESREQUEST
DESCRIPTOR.message_types_by_name['GetAllFeatureServicesResponse'] = _GETALLFEATURESERVICESRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureServiceSummaryRequest'] = _GETFEATURESERVICESUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureServiceSummaryResponse'] = _GETFEATURESERVICESUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualDataSourceSummaryRequest'] = _GETVIRTUALDATASOURCESUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetVirtualDataSourceSummaryResponse'] = _GETVIRTUALDATASOURCESUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GetTransformationSummaryRequest'] = _GETTRANSFORMATIONSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetTransformationSummaryResponse'] = _GETTRANSFORMATIONSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GetEntitySummaryRequest'] = _GETENTITYSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetEntitySummaryResponse'] = _GETENTITYSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['GetServingStatusRequest'] = _GETSERVINGSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetServingStatusResponse'] = _GETSERVINGSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetAllFeatureFreshnessRequest'] = _GETALLFEATUREFRESHNESSREQUEST
DESCRIPTOR.message_types_by_name['GetAllFeatureFreshnessResponse'] = _GETALLFEATUREFRESHNESSRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureFreshnessRequest'] = _GETFEATUREFRESHNESSREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureFreshnessResponse'] = _GETFEATUREFRESHNESSRESPONSE
DESCRIPTOR.message_types_by_name['GetMaterializationStatusRequest'] = _GETMATERIALIZATIONSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetMaterializationStatusResponse'] = _GETMATERIALIZATIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetAllMaterializationStatusInLiveWorkspacesRequest'] = _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST
DESCRIPTOR.message_types_by_name['FeatureViewMaterializationStatus'] = _FEATUREVIEWMATERIALIZATIONSTATUS
DESCRIPTOR.message_types_by_name['GetAllMaterializationStatusInLiveWorkspacesResponse'] = _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE
DESCRIPTOR.message_types_by_name['ForceRetryMaterializationTaskRequest'] = _FORCERETRYMATERIALIZATIONTASKREQUEST
DESCRIPTOR.message_types_by_name['ForceRetryMaterializationTaskResponse'] = _FORCERETRYMATERIALIZATIONTASKRESPONSE
DESCRIPTOR.message_types_by_name['GetFcosRequest'] = _GETFCOSREQUEST
DESCRIPTOR.message_types_by_name['GetFcosResponse'] = _GETFCOSRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureViewRequest'] = _GETFEATUREVIEWREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureViewResponse'] = _GETFEATUREVIEWRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureViewSummaryRequest'] = _GETFEATUREVIEWSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureViewSummaryResponse'] = _GETFEATUREVIEWSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeatureViewsRequest'] = _QUERYFEATUREVIEWSREQUEST
DESCRIPTOR.message_types_by_name['QueryFeatureViewsResponse'] = _QUERYFEATUREVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['GetMaterializingFeatureViewsInLiveWorkspacesResponse'] = _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualDataSourceRequest'] = _GETVIRTUALDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['GetVirtualDataSourceResponse'] = _GETVIRTUALDATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['GetAllVirtualDataSourcesRequest'] = _GETALLVIRTUALDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetAllVirtualDataSourcesResponse'] = _GETALLVIRTUALDATASOURCESRESPONSE
DESCRIPTOR.message_types_by_name['GetEntityRequest'] = _GETENTITYREQUEST
DESCRIPTOR.message_types_by_name['GetEntityResponse'] = _GETENTITYRESPONSE
DESCRIPTOR.message_types_by_name['GetAllEntitiesRequest'] = _GETALLENTITIESREQUEST
DESCRIPTOR.message_types_by_name['GetAllEntitiesResponse'] = _GETALLENTITIESRESPONSE
DESCRIPTOR.message_types_by_name['GetTransformationRequest'] = _GETTRANSFORMATIONREQUEST
DESCRIPTOR.message_types_by_name['GetTransformationResponse'] = _GETTRANSFORMATIONRESPONSE
DESCRIPTOR.message_types_by_name['GetAllTransformationsRequest'] = _GETALLTRANSFORMATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetAllTransformationsResponse'] = _GETALLTRANSFORMATIONSRESPONSE
DESCRIPTOR.message_types_by_name['FindFcoWorkspaceRequest'] = _FINDFCOWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['FindFcoWorkspaceResponse'] = _FINDFCOWORKSPACERESPONSE
DESCRIPTOR.message_types_by_name['IngestClientLogsRequest'] = _INGESTCLIENTLOGSREQUEST
DESCRIPTOR.message_types_by_name['IngestAnalyticsRequest'] = _INGESTANALYTICSREQUEST
DESCRIPTOR.message_types_by_name['NewStateUpdateRequest'] = _NEWSTATEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['NewStateUpdateResponse'] = _NEWSTATEUPDATERESPONSE
DESCRIPTOR.message_types_by_name['QueryStateUpdateRequest'] = _QUERYSTATEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['QueryStateUpdateResponse'] = _QUERYSTATEUPDATERESPONSE
DESCRIPTOR.message_types_by_name['ApplyStateUpdateRequest'] = _APPLYSTATEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ApplyStateUpdateResponse'] = _APPLYSTATEUPDATERESPONSE
DESCRIPTOR.message_types_by_name['GetConfigsResponse'] = _GETCONFIGSRESPONSE
DESCRIPTOR.message_types_by_name['GetStateUpdateLogRequest'] = _GETSTATEUPDATELOGREQUEST
DESCRIPTOR.message_types_by_name['GetStateUpdateLogResponse'] = _GETSTATEUPDATELOGRESPONSE
DESCRIPTOR.message_types_by_name['GetRestoreInfoRequest'] = _GETRESTOREINFOREQUEST
DESCRIPTOR.message_types_by_name['GetRestoreInfoResponse'] = _GETRESTOREINFORESPONSE
DESCRIPTOR.message_types_by_name['CreateWorkspaceRequest'] = _CREATEWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['DeleteWorkspaceRequest'] = _DELETEWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['CreateApiKeyRequest'] = _CREATEAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateApiKeyResponse'] = _CREATEAPIKEYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteApiKeyRequest'] = _DELETEAPIKEYREQUEST
DESCRIPTOR.message_types_by_name['ListApiKeysRequest'] = _LISTAPIKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListApiKeysResponse'] = _LISTAPIKEYSRESPONSE
DESCRIPTOR.message_types_by_name['ListWorkspacesRequest'] = _LISTWORKSPACESREQUEST
DESCRIPTOR.message_types_by_name['ListWorkspacesResponse'] = _LISTWORKSPACESRESPONSE
DESCRIPTOR.message_types_by_name['GetWorkspaceRequest'] = _GETWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetWorkspaceResponse'] = _GETWORKSPACERESPONSE
DESCRIPTOR.message_types_by_name['CreateSavedFeatureDataFrameRequest'] = _CREATESAVEDFEATUREDATAFRAMEREQUEST
DESCRIPTOR.message_types_by_name['CreateSavedFeatureDataFrameResponse'] = _CREATESAVEDFEATUREDATAFRAMERESPONSE
DESCRIPTOR.message_types_by_name['ArchiveSavedFeatureDataFrameRequest'] = _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST
DESCRIPTOR.message_types_by_name['ArchiveSavedFeatureDataFrameResponse'] = _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE
DESCRIPTOR.message_types_by_name['GetSavedFeatureDataFrameRequest'] = _GETSAVEDFEATUREDATAFRAMEREQUEST
DESCRIPTOR.message_types_by_name['GetClusterAdminInfoResponse'] = _GETCLUSTERADMININFORESPONSE
DESCRIPTOR.message_types_by_name['CreateClusterUserRequest'] = _CREATECLUSTERUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterUserResponse'] = _CREATECLUSTERUSERRESPONSE
DESCRIPTOR.message_types_by_name['DeleteClusterUserRequest'] = _DELETECLUSTERUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterUserResponse'] = _DELETECLUSTERUSERRESPONSE
DESCRIPTOR.message_types_by_name['ClusterUserActionRequest'] = _CLUSTERUSERACTIONREQUEST
DESCRIPTOR.message_types_by_name['ClusterUserActionResponse'] = _CLUSTERUSERACTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetSavedFeatureDataFrameResponse'] = _GETSAVEDFEATUREDATAFRAMERESPONSE
DESCRIPTOR.message_types_by_name['GetAllSavedFeatureDataFramesRequest'] = _GETALLSAVEDFEATUREDATAFRAMESREQUEST
DESCRIPTOR.message_types_by_name['GetAllSavedFeatureDataFramesResponse'] = _GETALLSAVEDFEATUREDATAFRAMESRESPONSE
DESCRIPTOR.message_types_by_name['IngestDataframeRequest'] = _INGESTDATAFRAMEREQUEST
DESCRIPTOR.message_types_by_name['IngestDataframeResponse'] = _INGESTDATAFRAMERESPONSE
DESCRIPTOR.message_types_by_name['GetNewIngestDataframeInfoRequest'] = _GETNEWINGESTDATAFRAMEINFOREQUEST
DESCRIPTOR.message_types_by_name['GetNewIngestDataframeInfoResponse'] = _GETNEWINGESTDATAFRAMEINFORESPONSE
DESCRIPTOR.message_types_by_name['GetUserDeploymentSettingsResponse'] = _GETUSERDEPLOYMENTSETTINGSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserDeploymentSettingsRequest'] = _UPDATEUSERDEPLOYMENTSETTINGSREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserDeploymentSettingsResponse'] = _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE
DESCRIPTOR.message_types_by_name['GetInternalSparkClusterStatusResponse'] = _GETINTERNALSPARKCLUSTERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['GetDeleteEntitiesInfoRequest'] = _GETDELETEENTITIESINFOREQUEST
DESCRIPTOR.message_types_by_name['GetDeleteEntitiesInfoResponse'] = _GETDELETEENTITIESINFORESPONSE
DESCRIPTOR.message_types_by_name['DeleteEntitiesRequest'] = _DELETEENTITIESREQUEST
DESCRIPTOR.message_types_by_name['DeleteEntitiesResponse'] = _DELETEENTITIESRESPONSE
DESCRIPTOR.extensions_by_name['allow_in_standard_user_role'] = allow_in_standard_user_role
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeatureServiceRequest = _reflection.GeneratedProtocolMessageType('GetFeatureServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESERVICEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureServiceRequest)
  })
_sym_db.RegisterMessage(GetFeatureServiceRequest)

GetFeatureServiceResponse = _reflection.GeneratedProtocolMessageType('GetFeatureServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESERVICERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureServiceResponse)
  })
_sym_db.RegisterMessage(GetFeatureServiceResponse)

GetAllFeatureServicesRequest = _reflection.GeneratedProtocolMessageType('GetAllFeatureServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESERVICESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllFeatureServicesRequest)
  })
_sym_db.RegisterMessage(GetAllFeatureServicesRequest)

GetAllFeatureServicesResponse = _reflection.GeneratedProtocolMessageType('GetAllFeatureServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATURESERVICESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllFeatureServicesResponse)
  })
_sym_db.RegisterMessage(GetAllFeatureServicesResponse)

GetFeatureServiceSummaryRequest = _reflection.GeneratedProtocolMessageType('GetFeatureServiceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESERVICESUMMARYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureServiceSummaryRequest)
  })
_sym_db.RegisterMessage(GetFeatureServiceSummaryRequest)

GetFeatureServiceSummaryResponse = _reflection.GeneratedProtocolMessageType('GetFeatureServiceSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESERVICESUMMARYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureServiceSummaryResponse)
  })
_sym_db.RegisterMessage(GetFeatureServiceSummaryResponse)

GetVirtualDataSourceSummaryRequest = _reflection.GeneratedProtocolMessageType('GetVirtualDataSourceSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALDATASOURCESUMMARYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetVirtualDataSourceSummaryRequest)
  })
_sym_db.RegisterMessage(GetVirtualDataSourceSummaryRequest)

GetVirtualDataSourceSummaryResponse = _reflection.GeneratedProtocolMessageType('GetVirtualDataSourceSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALDATASOURCESUMMARYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetVirtualDataSourceSummaryResponse)
  })
_sym_db.RegisterMessage(GetVirtualDataSourceSummaryResponse)

GetTransformationSummaryRequest = _reflection.GeneratedProtocolMessageType('GetTransformationSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONSUMMARYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetTransformationSummaryRequest)
  })
_sym_db.RegisterMessage(GetTransformationSummaryRequest)

GetTransformationSummaryResponse = _reflection.GeneratedProtocolMessageType('GetTransformationSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONSUMMARYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetTransformationSummaryResponse)
  })
_sym_db.RegisterMessage(GetTransformationSummaryResponse)

GetEntitySummaryRequest = _reflection.GeneratedProtocolMessageType('GetEntitySummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYSUMMARYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetEntitySummaryRequest)
  })
_sym_db.RegisterMessage(GetEntitySummaryRequest)

GetEntitySummaryResponse = _reflection.GeneratedProtocolMessageType('GetEntitySummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYSUMMARYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetEntitySummaryResponse)
  })
_sym_db.RegisterMessage(GetEntitySummaryResponse)

GetServingStatusRequest = _reflection.GeneratedProtocolMessageType('GetServingStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSTATUSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetServingStatusRequest)
  })
_sym_db.RegisterMessage(GetServingStatusRequest)

GetServingStatusResponse = _reflection.GeneratedProtocolMessageType('GetServingStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSTATUSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetServingStatusResponse)
  })
_sym_db.RegisterMessage(GetServingStatusResponse)

GetAllFeatureFreshnessRequest = _reflection.GeneratedProtocolMessageType('GetAllFeatureFreshnessRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATUREFRESHNESSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllFeatureFreshnessRequest)
  })
_sym_db.RegisterMessage(GetAllFeatureFreshnessRequest)

GetAllFeatureFreshnessResponse = _reflection.GeneratedProtocolMessageType('GetAllFeatureFreshnessResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLFEATUREFRESHNESSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllFeatureFreshnessResponse)
  })
_sym_db.RegisterMessage(GetAllFeatureFreshnessResponse)

GetFeatureFreshnessRequest = _reflection.GeneratedProtocolMessageType('GetFeatureFreshnessRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREFRESHNESSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureFreshnessRequest)
  })
_sym_db.RegisterMessage(GetFeatureFreshnessRequest)

GetFeatureFreshnessResponse = _reflection.GeneratedProtocolMessageType('GetFeatureFreshnessResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREFRESHNESSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureFreshnessResponse)
  })
_sym_db.RegisterMessage(GetFeatureFreshnessResponse)

GetMaterializationStatusRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONSTATUSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetMaterializationStatusRequest)
  })
_sym_db.RegisterMessage(GetMaterializationStatusRequest)

GetMaterializationStatusResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONSTATUSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetMaterializationStatusResponse)
  })
_sym_db.RegisterMessage(GetMaterializationStatusResponse)

GetAllMaterializationStatusInLiveWorkspacesRequest = _reflection.GeneratedProtocolMessageType('GetAllMaterializationStatusInLiveWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesRequest)
  })
_sym_db.RegisterMessage(GetAllMaterializationStatusInLiveWorkspacesRequest)

FeatureViewMaterializationStatus = _reflection.GeneratedProtocolMessageType('FeatureViewMaterializationStatus', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWMATERIALIZATIONSTATUS,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.FeatureViewMaterializationStatus)
  })
_sym_db.RegisterMessage(FeatureViewMaterializationStatus)

GetAllMaterializationStatusInLiveWorkspacesResponse = _reflection.GeneratedProtocolMessageType('GetAllMaterializationStatusInLiveWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllMaterializationStatusInLiveWorkspacesResponse)
  })
_sym_db.RegisterMessage(GetAllMaterializationStatusInLiveWorkspacesResponse)

ForceRetryMaterializationTaskRequest = _reflection.GeneratedProtocolMessageType('ForceRetryMaterializationTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _FORCERETRYMATERIALIZATIONTASKREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ForceRetryMaterializationTaskRequest)
  })
_sym_db.RegisterMessage(ForceRetryMaterializationTaskRequest)

ForceRetryMaterializationTaskResponse = _reflection.GeneratedProtocolMessageType('ForceRetryMaterializationTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _FORCERETRYMATERIALIZATIONTASKRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ForceRetryMaterializationTaskResponse)
  })
_sym_db.RegisterMessage(ForceRetryMaterializationTaskResponse)

GetFcosRequest = _reflection.GeneratedProtocolMessageType('GetFcosRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFCOSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFcosRequest)
  })
_sym_db.RegisterMessage(GetFcosRequest)

GetFcosResponse = _reflection.GeneratedProtocolMessageType('GetFcosResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFCOSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFcosResponse)
  })
_sym_db.RegisterMessage(GetFcosResponse)

GetFeatureViewRequest = _reflection.GeneratedProtocolMessageType('GetFeatureViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureViewRequest)
  })
_sym_db.RegisterMessage(GetFeatureViewRequest)

GetFeatureViewResponse = _reflection.GeneratedProtocolMessageType('GetFeatureViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureViewResponse)
  })
_sym_db.RegisterMessage(GetFeatureViewResponse)

GetFeatureViewSummaryRequest = _reflection.GeneratedProtocolMessageType('GetFeatureViewSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWSUMMARYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureViewSummaryRequest)
  })
_sym_db.RegisterMessage(GetFeatureViewSummaryRequest)

GetFeatureViewSummaryResponse = _reflection.GeneratedProtocolMessageType('GetFeatureViewSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWSUMMARYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetFeatureViewSummaryResponse)
  })
_sym_db.RegisterMessage(GetFeatureViewSummaryResponse)

QueryFeatureViewsRequest = _reflection.GeneratedProtocolMessageType('QueryFeatureViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEATUREVIEWSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.QueryFeatureViewsRequest)
  })
_sym_db.RegisterMessage(QueryFeatureViewsRequest)

QueryFeatureViewsResponse = _reflection.GeneratedProtocolMessageType('QueryFeatureViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEATUREVIEWSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.QueryFeatureViewsResponse)
  })
_sym_db.RegisterMessage(QueryFeatureViewsResponse)

GetMaterializingFeatureViewsInLiveWorkspacesResponse = _reflection.GeneratedProtocolMessageType('GetMaterializingFeatureViewsInLiveWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetMaterializingFeatureViewsInLiveWorkspacesResponse)
  })
_sym_db.RegisterMessage(GetMaterializingFeatureViewsInLiveWorkspacesResponse)

GetVirtualDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetVirtualDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALDATASOURCEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetVirtualDataSourceRequest)
  })
_sym_db.RegisterMessage(GetVirtualDataSourceRequest)

GetVirtualDataSourceResponse = _reflection.GeneratedProtocolMessageType('GetVirtualDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALDATASOURCERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetVirtualDataSourceResponse)
  })
_sym_db.RegisterMessage(GetVirtualDataSourceResponse)

GetAllVirtualDataSourcesRequest = _reflection.GeneratedProtocolMessageType('GetAllVirtualDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLVIRTUALDATASOURCESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllVirtualDataSourcesRequest)
  })
_sym_db.RegisterMessage(GetAllVirtualDataSourcesRequest)

GetAllVirtualDataSourcesResponse = _reflection.GeneratedProtocolMessageType('GetAllVirtualDataSourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLVIRTUALDATASOURCESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllVirtualDataSourcesResponse)
  })
_sym_db.RegisterMessage(GetAllVirtualDataSourcesResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

GetEntityResponse = _reflection.GeneratedProtocolMessageType('GetEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetEntityResponse)
  })
_sym_db.RegisterMessage(GetEntityResponse)

GetAllEntitiesRequest = _reflection.GeneratedProtocolMessageType('GetAllEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLENTITIESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllEntitiesRequest)
  })
_sym_db.RegisterMessage(GetAllEntitiesRequest)

GetAllEntitiesResponse = _reflection.GeneratedProtocolMessageType('GetAllEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLENTITIESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllEntitiesResponse)
  })
_sym_db.RegisterMessage(GetAllEntitiesResponse)

GetTransformationRequest = _reflection.GeneratedProtocolMessageType('GetTransformationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetTransformationRequest)
  })
_sym_db.RegisterMessage(GetTransformationRequest)

GetTransformationResponse = _reflection.GeneratedProtocolMessageType('GetTransformationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFORMATIONRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetTransformationResponse)
  })
_sym_db.RegisterMessage(GetTransformationResponse)

GetAllTransformationsRequest = _reflection.GeneratedProtocolMessageType('GetAllTransformationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLTRANSFORMATIONSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllTransformationsRequest)
  })
_sym_db.RegisterMessage(GetAllTransformationsRequest)

GetAllTransformationsResponse = _reflection.GeneratedProtocolMessageType('GetAllTransformationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLTRANSFORMATIONSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllTransformationsResponse)
  })
_sym_db.RegisterMessage(GetAllTransformationsResponse)

FindFcoWorkspaceRequest = _reflection.GeneratedProtocolMessageType('FindFcoWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDFCOWORKSPACEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.FindFcoWorkspaceRequest)
  })
_sym_db.RegisterMessage(FindFcoWorkspaceRequest)

FindFcoWorkspaceResponse = _reflection.GeneratedProtocolMessageType('FindFcoWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDFCOWORKSPACERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.FindFcoWorkspaceResponse)
  })
_sym_db.RegisterMessage(FindFcoWorkspaceResponse)

IngestClientLogsRequest = _reflection.GeneratedProtocolMessageType('IngestClientLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INGESTCLIENTLOGSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.IngestClientLogsRequest)
  })
_sym_db.RegisterMessage(IngestClientLogsRequest)

IngestAnalyticsRequest = _reflection.GeneratedProtocolMessageType('IngestAnalyticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INGESTANALYTICSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.IngestAnalyticsRequest)
  })
_sym_db.RegisterMessage(IngestAnalyticsRequest)

NewStateUpdateRequest = _reflection.GeneratedProtocolMessageType('NewStateUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWSTATEUPDATEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.NewStateUpdateRequest)
  })
_sym_db.RegisterMessage(NewStateUpdateRequest)

NewStateUpdateResponse = _reflection.GeneratedProtocolMessageType('NewStateUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWSTATEUPDATERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.NewStateUpdateResponse)
  })
_sym_db.RegisterMessage(NewStateUpdateResponse)

QueryStateUpdateRequest = _reflection.GeneratedProtocolMessageType('QueryStateUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATEUPDATEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.QueryStateUpdateRequest)
  })
_sym_db.RegisterMessage(QueryStateUpdateRequest)

QueryStateUpdateResponse = _reflection.GeneratedProtocolMessageType('QueryStateUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSTATEUPDATERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.QueryStateUpdateResponse)
  })
_sym_db.RegisterMessage(QueryStateUpdateResponse)

ApplyStateUpdateRequest = _reflection.GeneratedProtocolMessageType('ApplyStateUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYSTATEUPDATEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ApplyStateUpdateRequest)
  })
_sym_db.RegisterMessage(ApplyStateUpdateRequest)

ApplyStateUpdateResponse = _reflection.GeneratedProtocolMessageType('ApplyStateUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYSTATEUPDATERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ApplyStateUpdateResponse)
  })
_sym_db.RegisterMessage(ApplyStateUpdateResponse)

GetConfigsResponse = _reflection.GeneratedProtocolMessageType('GetConfigsResponse', (_message.Message,), {

  'KeyValuesEntry' : _reflection.GeneratedProtocolMessageType('KeyValuesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONFIGSRESPONSE_KEYVALUESENTRY,
    '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetConfigsResponse.KeyValuesEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONFIGSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetConfigsResponse)
  })
_sym_db.RegisterMessage(GetConfigsResponse)
_sym_db.RegisterMessage(GetConfigsResponse.KeyValuesEntry)

GetStateUpdateLogRequest = _reflection.GeneratedProtocolMessageType('GetStateUpdateLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEUPDATELOGREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetStateUpdateLogRequest)
  })
_sym_db.RegisterMessage(GetStateUpdateLogRequest)

GetStateUpdateLogResponse = _reflection.GeneratedProtocolMessageType('GetStateUpdateLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEUPDATELOGRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetStateUpdateLogResponse)
  })
_sym_db.RegisterMessage(GetStateUpdateLogResponse)

GetRestoreInfoRequest = _reflection.GeneratedProtocolMessageType('GetRestoreInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESTOREINFOREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetRestoreInfoRequest)
  })
_sym_db.RegisterMessage(GetRestoreInfoRequest)

GetRestoreInfoResponse = _reflection.GeneratedProtocolMessageType('GetRestoreInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESTOREINFORESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetRestoreInfoResponse)
  })
_sym_db.RegisterMessage(GetRestoreInfoResponse)

CreateWorkspaceRequest = _reflection.GeneratedProtocolMessageType('CreateWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWORKSPACEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateWorkspaceRequest)
  })
_sym_db.RegisterMessage(CreateWorkspaceRequest)

DeleteWorkspaceRequest = _reflection.GeneratedProtocolMessageType('DeleteWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWORKSPACEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteWorkspaceRequest)
  })
_sym_db.RegisterMessage(DeleteWorkspaceRequest)

CreateApiKeyRequest = _reflection.GeneratedProtocolMessageType('CreateApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateApiKeyRequest)
  })
_sym_db.RegisterMessage(CreateApiKeyRequest)

CreateApiKeyResponse = _reflection.GeneratedProtocolMessageType('CreateApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateApiKeyResponse)
  })
_sym_db.RegisterMessage(CreateApiKeyResponse)

DeleteApiKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPIKEYREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteApiKeyRequest)
  })
_sym_db.RegisterMessage(DeleteApiKeyRequest)

ListApiKeysRequest = _reflection.GeneratedProtocolMessageType('ListApiKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ListApiKeysRequest)
  })
_sym_db.RegisterMessage(ListApiKeysRequest)

ListApiKeysResponse = _reflection.GeneratedProtocolMessageType('ListApiKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ListApiKeysResponse)
  })
_sym_db.RegisterMessage(ListApiKeysResponse)

ListWorkspacesRequest = _reflection.GeneratedProtocolMessageType('ListWorkspacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ListWorkspacesRequest)
  })
_sym_db.RegisterMessage(ListWorkspacesRequest)

ListWorkspacesResponse = _reflection.GeneratedProtocolMessageType('ListWorkspacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKSPACESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ListWorkspacesResponse)
  })
_sym_db.RegisterMessage(ListWorkspacesResponse)

GetWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetWorkspaceRequest)
  })
_sym_db.RegisterMessage(GetWorkspaceRequest)

GetWorkspaceResponse = _reflection.GeneratedProtocolMessageType('GetWorkspaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetWorkspaceResponse)
  })
_sym_db.RegisterMessage(GetWorkspaceResponse)

CreateSavedFeatureDataFrameRequest = _reflection.GeneratedProtocolMessageType('CreateSavedFeatureDataFrameRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESAVEDFEATUREDATAFRAMEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateSavedFeatureDataFrameRequest)
  })
_sym_db.RegisterMessage(CreateSavedFeatureDataFrameRequest)

CreateSavedFeatureDataFrameResponse = _reflection.GeneratedProtocolMessageType('CreateSavedFeatureDataFrameResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESAVEDFEATUREDATAFRAMERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateSavedFeatureDataFrameResponse)
  })
_sym_db.RegisterMessage(CreateSavedFeatureDataFrameResponse)

ArchiveSavedFeatureDataFrameRequest = _reflection.GeneratedProtocolMessageType('ArchiveSavedFeatureDataFrameRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESAVEDFEATUREDATAFRAMEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameRequest)
  })
_sym_db.RegisterMessage(ArchiveSavedFeatureDataFrameRequest)

ArchiveSavedFeatureDataFrameResponse = _reflection.GeneratedProtocolMessageType('ArchiveSavedFeatureDataFrameResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVESAVEDFEATUREDATAFRAMERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ArchiveSavedFeatureDataFrameResponse)
  })
_sym_db.RegisterMessage(ArchiveSavedFeatureDataFrameResponse)

GetSavedFeatureDataFrameRequest = _reflection.GeneratedProtocolMessageType('GetSavedFeatureDataFrameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVEDFEATUREDATAFRAMEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetSavedFeatureDataFrameRequest)
  })
_sym_db.RegisterMessage(GetSavedFeatureDataFrameRequest)

GetClusterAdminInfoResponse = _reflection.GeneratedProtocolMessageType('GetClusterAdminInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERADMININFORESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetClusterAdminInfoResponse)
  })
_sym_db.RegisterMessage(GetClusterAdminInfoResponse)

CreateClusterUserRequest = _reflection.GeneratedProtocolMessageType('CreateClusterUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERUSERREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateClusterUserRequest)
  })
_sym_db.RegisterMessage(CreateClusterUserRequest)

CreateClusterUserResponse = _reflection.GeneratedProtocolMessageType('CreateClusterUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERUSERRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.CreateClusterUserResponse)
  })
_sym_db.RegisterMessage(CreateClusterUserResponse)

DeleteClusterUserRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERUSERREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteClusterUserRequest)
  })
_sym_db.RegisterMessage(DeleteClusterUserRequest)

DeleteClusterUserResponse = _reflection.GeneratedProtocolMessageType('DeleteClusterUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERUSERRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteClusterUserResponse)
  })
_sym_db.RegisterMessage(DeleteClusterUserResponse)

ClusterUserActionRequest = _reflection.GeneratedProtocolMessageType('ClusterUserActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERUSERACTIONREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ClusterUserActionRequest)
  })
_sym_db.RegisterMessage(ClusterUserActionRequest)

ClusterUserActionResponse = _reflection.GeneratedProtocolMessageType('ClusterUserActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERUSERACTIONRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.ClusterUserActionResponse)
  })
_sym_db.RegisterMessage(ClusterUserActionResponse)

GetSavedFeatureDataFrameResponse = _reflection.GeneratedProtocolMessageType('GetSavedFeatureDataFrameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVEDFEATUREDATAFRAMERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetSavedFeatureDataFrameResponse)
  })
_sym_db.RegisterMessage(GetSavedFeatureDataFrameResponse)

GetAllSavedFeatureDataFramesRequest = _reflection.GeneratedProtocolMessageType('GetAllSavedFeatureDataFramesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLSAVEDFEATUREDATAFRAMESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllSavedFeatureDataFramesRequest)
  })
_sym_db.RegisterMessage(GetAllSavedFeatureDataFramesRequest)

GetAllSavedFeatureDataFramesResponse = _reflection.GeneratedProtocolMessageType('GetAllSavedFeatureDataFramesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALLSAVEDFEATUREDATAFRAMESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetAllSavedFeatureDataFramesResponse)
  })
_sym_db.RegisterMessage(GetAllSavedFeatureDataFramesResponse)

IngestDataframeRequest = _reflection.GeneratedProtocolMessageType('IngestDataframeRequest', (_message.Message,), {
  'DESCRIPTOR' : _INGESTDATAFRAMEREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.IngestDataframeRequest)
  })
_sym_db.RegisterMessage(IngestDataframeRequest)

IngestDataframeResponse = _reflection.GeneratedProtocolMessageType('IngestDataframeResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTDATAFRAMERESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.IngestDataframeResponse)
  })
_sym_db.RegisterMessage(IngestDataframeResponse)

GetNewIngestDataframeInfoRequest = _reflection.GeneratedProtocolMessageType('GetNewIngestDataframeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWINGESTDATAFRAMEINFOREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetNewIngestDataframeInfoRequest)
  })
_sym_db.RegisterMessage(GetNewIngestDataframeInfoRequest)

GetNewIngestDataframeInfoResponse = _reflection.GeneratedProtocolMessageType('GetNewIngestDataframeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEWINGESTDATAFRAMEINFORESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetNewIngestDataframeInfoResponse)
  })
_sym_db.RegisterMessage(GetNewIngestDataframeInfoResponse)

GetUserDeploymentSettingsResponse = _reflection.GeneratedProtocolMessageType('GetUserDeploymentSettingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERDEPLOYMENTSETTINGSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetUserDeploymentSettingsResponse)
  })
_sym_db.RegisterMessage(GetUserDeploymentSettingsResponse)

UpdateUserDeploymentSettingsRequest = _reflection.GeneratedProtocolMessageType('UpdateUserDeploymentSettingsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERDEPLOYMENTSETTINGSREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.UpdateUserDeploymentSettingsRequest)
  })
_sym_db.RegisterMessage(UpdateUserDeploymentSettingsRequest)

UpdateUserDeploymentSettingsResponse = _reflection.GeneratedProtocolMessageType('UpdateUserDeploymentSettingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERDEPLOYMENTSETTINGSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.UpdateUserDeploymentSettingsResponse)
  })
_sym_db.RegisterMessage(UpdateUserDeploymentSettingsResponse)

GetInternalSparkClusterStatusResponse = _reflection.GeneratedProtocolMessageType('GetInternalSparkClusterStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERNALSPARKCLUSTERSTATUSRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetInternalSparkClusterStatusResponse)
  })
_sym_db.RegisterMessage(GetInternalSparkClusterStatusResponse)

GetDeleteEntitiesInfoRequest = _reflection.GeneratedProtocolMessageType('GetDeleteEntitiesInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDELETEENTITIESINFOREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetDeleteEntitiesInfoRequest)
  })
_sym_db.RegisterMessage(GetDeleteEntitiesInfoRequest)

GetDeleteEntitiesInfoResponse = _reflection.GeneratedProtocolMessageType('GetDeleteEntitiesInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDELETEENTITIESINFORESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.GetDeleteEntitiesInfoResponse)
  })
_sym_db.RegisterMessage(GetDeleteEntitiesInfoResponse)

DeleteEntitiesRequest = _reflection.GeneratedProtocolMessageType('DeleteEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITIESREQUEST,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteEntitiesRequest)
  })
_sym_db.RegisterMessage(DeleteEntitiesRequest)

DeleteEntitiesResponse = _reflection.GeneratedProtocolMessageType('DeleteEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITIESRESPONSE,
  '__module__' : 'tecton_proto.metadataservice.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.metadataservice.DeleteEntitiesResponse)
  })
_sym_db.RegisterMessage(DeleteEntitiesResponse)

google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(allow_in_standard_user_role)

DESCRIPTOR._options = None
_GETFEATURESERVICERESPONSE.fields_by_name['feature_service']._options = None
_GETFEATUREVIEWRESPONSE.fields_by_name['feature_view']._options = None
_QUERYFEATUREVIEWSRESPONSE.fields_by_name['feature_views']._options = None
_APPLYSTATEUPDATEREQUEST.fields_by_name['applied_by']._options = None
_GETCONFIGSRESPONSE_KEYVALUESENTRY._options = None

_METADATASERVICE = _descriptor.ServiceDescriptor(
  name='MetadataService',
  full_name='tecton_proto.metadataservice.MetadataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=13533,
  serialized_end=23189,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeatureService',
    full_name='tecton_proto.metadataservice.MetadataService.GetFeatureService',
    index=0,
    containing_service=None,
    input_type=_GETFEATURESERVICEREQUEST,
    output_type=_GETFEATURESERVICERESPONSE,
    serialized_options=b'\202\323\344\223\002-\"(/v1/metadata-service/get-feature-service:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllFeatureServices',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllFeatureServices',
    index=1,
    containing_service=None,
    input_type=_GETALLFEATURESERVICESREQUEST,
    output_type=_GETALLFEATURESERVICESRESPONSE,
    serialized_options=b'\202\323\344\223\0022\"-/v1/metadata-service/get-all-feature-services:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureServiceSummary',
    full_name='tecton_proto.metadataservice.MetadataService.GetFeatureServiceSummary',
    index=2,
    containing_service=None,
    input_type=_GETFEATURESERVICESUMMARYREQUEST,
    output_type=_GETFEATURESERVICESUMMARYRESPONSE,
    serialized_options=b'\202\323\344\223\0025\"0/v1/metadata-service/get-feature-service-summary:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServingStatus',
    full_name='tecton_proto.metadataservice.MetadataService.GetServingStatus',
    index=3,
    containing_service=None,
    input_type=_GETSERVINGSTATUSREQUEST,
    output_type=_GETSERVINGSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/metadata-service/get-serving-status:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllFeatureFreshness',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllFeatureFreshness',
    index=4,
    containing_service=None,
    input_type=_GETALLFEATUREFRESHNESSREQUEST,
    output_type=_GETALLFEATUREFRESHNESSRESPONSE,
    serialized_options=b'\202\323\344\223\0023\"./v1/metadata-service/get-all-feature-freshness:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureFreshness',
    full_name='tecton_proto.metadataservice.MetadataService.GetFeatureFreshness',
    index=5,
    containing_service=None,
    input_type=_GETFEATUREFRESHNESSREQUEST,
    output_type=_GETFEATUREFRESHNESSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\"*/v1/metadata-service/get-feature-freshness:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaterializationStatus',
    full_name='tecton_proto.metadataservice.MetadataService.GetMaterializationStatus',
    index=6,
    containing_service=None,
    input_type=_GETMATERIALIZATIONSTATUSREQUEST,
    output_type=_GETMATERIALIZATIONSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//v1/metadata-service/get-materialization-status:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllMaterializationStatusInLiveWorkspaces',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllMaterializationStatusInLiveWorkspaces',
    index=7,
    containing_service=None,
    input_type=_GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESREQUEST,
    output_type=_GETALLMATERIALIZATIONSTATUSINLIVEWORKSPACESRESPONSE,
    serialized_options=b'\202\323\344\223\002J\"E/v1/metadata-service/get-all-materialization-status-in-live-workspace:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ForceRetryMaterializationTask',
    full_name='tecton_proto.metadataservice.MetadataService.ForceRetryMaterializationTask',
    index=8,
    containing_service=None,
    input_type=_FORCERETRYMATERIALIZATIONTASKREQUEST,
    output_type=_FORCERETRYMATERIALIZATIONTASKRESPONSE,
    serialized_options=b'\202\323\344\223\002:\"5/v1/metadata-service/force-retry-materialization-task:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureView',
    full_name='tecton_proto.metadataservice.MetadataService.GetFeatureView',
    index=9,
    containing_service=None,
    input_type=_GETFEATUREVIEWREQUEST,
    output_type=_GETFEATUREVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"%/v1/metadata-service/get-feature-view:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaterializingFeatureViewsInLiveWorkspaces',
    full_name='tecton_proto.metadataservice.MetadataService.GetMaterializingFeatureViewsInLiveWorkspaces',
    index=10,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETMATERIALIZINGFEATUREVIEWSINLIVEWORKSPACESRESPONSE,
    serialized_options=b'\202\323\344\223\002F\"A/v1/metadata-service/get-materializing-features-in-live-workspace:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryFeatureViews',
    full_name='tecton_proto.metadataservice.MetadataService.QueryFeatureViews',
    index=11,
    containing_service=None,
    input_type=_QUERYFEATUREVIEWSREQUEST,
    output_type=_QUERYFEATUREVIEWSRESPONSE,
    serialized_options=b'\202\323\344\223\002-\"(/v1/metadata-service/query-feature-views:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureViewSummary',
    full_name='tecton_proto.metadataservice.MetadataService.GetFeatureViewSummary',
    index=12,
    containing_service=None,
    input_type=_GETFEATUREVIEWSUMMARYREQUEST,
    output_type=_GETFEATUREVIEWSUMMARYRESPONSE,
    serialized_options=b'\202\323\344\223\0022\"-/v1/metadata-package/get-feature-view-summary:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualDataSource',
    full_name='tecton_proto.metadataservice.MetadataService.GetVirtualDataSource',
    index=13,
    containing_service=None,
    input_type=_GETVIRTUALDATASOURCEREQUEST,
    output_type=_GETVIRTUALDATASOURCERESPONSE,
    serialized_options=b'\202\323\344\223\0021\",/v1/metadata-service/get-virtual-data-source:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllVirtualDataSources',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllVirtualDataSources',
    index=14,
    containing_service=None,
    input_type=_GETALLVIRTUALDATASOURCESREQUEST,
    output_type=_GETALLVIRTUALDATASOURCESRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/v1/metadata-service/get-all-virtual-data-sources:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IngestClientLogs',
    full_name='tecton_proto.metadataservice.MetadataService.IngestClientLogs',
    index=15,
    containing_service=None,
    input_type=_INGESTCLIENTLOGSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IngestAnalytics',
    full_name='tecton_proto.metadataservice.MetadataService.IngestAnalytics',
    index=16,
    containing_service=None,
    input_type=_INGESTANALYTICSREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\"%/v1/metadata-service/ingest-analytics:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualDataSourceSummary',
    full_name='tecton_proto.metadataservice.MetadataService.GetVirtualDataSourceSummary',
    index=17,
    containing_service=None,
    input_type=_GETVIRTUALDATASOURCESUMMARYREQUEST,
    output_type=_GETVIRTUALDATASOURCESUMMARYRESPONSE,
    serialized_options=b'\202\323\344\223\0029\"4/v1/metadata-service/get-virtual-data-source-summary:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFcos',
    full_name='tecton_proto.metadataservice.MetadataService.GetFcos',
    index=18,
    containing_service=None,
    input_type=_GETFCOSREQUEST,
    output_type=_GETFCOSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/metadata-service/get-fcos:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEntity',
    full_name='tecton_proto.metadataservice.MetadataService.GetEntity',
    index=19,
    containing_service=None,
    input_type=_GETENTITYREQUEST,
    output_type=_GETENTITYRESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllEntities',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllEntities',
    index=20,
    containing_service=None,
    input_type=_GETALLENTITIESREQUEST,
    output_type=_GETALLENTITIESRESPONSE,
    serialized_options=b'\202\323\344\223\002*\"%/v1/metadata-service/get-all-entities:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEntitySummary',
    full_name='tecton_proto.metadataservice.MetadataService.GetEntitySummary',
    index=21,
    containing_service=None,
    input_type=_GETENTITYSUMMARYREQUEST,
    output_type=_GETENTITYSUMMARYRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/metadata-package/get-entity-summary:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransformation',
    full_name='tecton_proto.metadataservice.MetadataService.GetTransformation',
    index=22,
    containing_service=None,
    input_type=_GETTRANSFORMATIONREQUEST,
    output_type=_GETTRANSFORMATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/metadata-service/get-transformation:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllTransformations',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllTransformations',
    index=23,
    containing_service=None,
    input_type=_GETALLTRANSFORMATIONSREQUEST,
    output_type=_GETALLTRANSFORMATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\",/v1/metadata-service/get-all-transformations:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransformationSummary',
    full_name='tecton_proto.metadataservice.MetadataService.GetTransformationSummary',
    index=24,
    containing_service=None,
    input_type=_GETTRANSFORMATIONSUMMARYREQUEST,
    output_type=_GETTRANSFORMATIONSUMMARYRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//v1/metadata-package/get-transformation-summary:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindFcoWorkspace',
    full_name='tecton_proto.metadataservice.MetadataService.FindFcoWorkspace',
    index=25,
    containing_service=None,
    input_type=_FINDFCOWORKSPACEREQUEST,
    output_type=_FINDFCOWORKSPACERESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\'/v1/metadata-service/find-fco-workspace:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewStateUpdate',
    full_name='tecton_proto.metadataservice.MetadataService.NewStateUpdate',
    index=26,
    containing_service=None,
    input_type=_NEWSTATEUPDATEREQUEST,
    output_type=_NEWSTATEUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryStateUpdate',
    full_name='tecton_proto.metadataservice.MetadataService.QueryStateUpdate',
    index=27,
    containing_service=None,
    input_type=_QUERYSTATEUPDATEREQUEST,
    output_type=_QUERYSTATEUPDATERESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ApplyStateUpdate',
    full_name='tecton_proto.metadataservice.MetadataService.ApplyStateUpdate',
    index=28,
    containing_service=None,
    input_type=_APPLYSTATEUPDATEREQUEST,
    output_type=_APPLYSTATEUPDATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfigs',
    full_name='tecton_proto.metadataservice.MetadataService.GetConfigs',
    index=29,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCONFIGSRESPONSE,
    serialized_options=b'\202\323\344\223\002%\" /v1/metadata-service/get-configs:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Nop',
    full_name='tecton_proto.metadataservice.MetadataService.Nop',
    index=30,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStateUpdateLog',
    full_name='tecton_proto.metadataservice.MetadataService.GetStateUpdateLog',
    index=31,
    containing_service=None,
    input_type=_GETSTATEUPDATELOGREQUEST,
    output_type=_GETSTATEUPDATELOGRESPONSE,
    serialized_options=b'\202\323\344\223\002.\")/v1/metadata-service/get-state-update-log:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRestoreInfo',
    full_name='tecton_proto.metadataservice.MetadataService.GetRestoreInfo',
    index=32,
    containing_service=None,
    input_type=_GETRESTOREINFOREQUEST,
    output_type=_GETRESTOREINFORESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateWorkspace',
    full_name='tecton_proto.metadataservice.MetadataService.CreateWorkspace',
    index=33,
    containing_service=None,
    input_type=_CREATEWORKSPACEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWorkspace',
    full_name='tecton_proto.metadataservice.MetadataService.DeleteWorkspace',
    index=34,
    containing_service=None,
    input_type=_DELETEWORKSPACEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListWorkspaces',
    full_name='tecton_proto.metadataservice.MetadataService.ListWorkspaces',
    index=35,
    containing_service=None,
    input_type=_LISTWORKSPACESREQUEST,
    output_type=_LISTWORKSPACESRESPONSE,
    serialized_options=b'\202\323\344\223\002)\"$/v1/metadata-service/list-workspaces:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkspace',
    full_name='tecton_proto.metadataservice.MetadataService.GetWorkspace',
    index=36,
    containing_service=None,
    input_type=_GETWORKSPACEREQUEST,
    output_type=_GETWORKSPACERESPONSE,
    serialized_options=b'\202\323\344\223\002\'\"\"/v1/metadata-service/get-workspace:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiKey',
    full_name='tecton_proto.metadataservice.MetadataService.CreateApiKey',
    index=37,
    containing_service=None,
    input_type=_CREATEAPIKEYREQUEST,
    output_type=_CREATEAPIKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteApiKey',
    full_name='tecton_proto.metadataservice.MetadataService.DeleteApiKey',
    index=38,
    containing_service=None,
    input_type=_DELETEAPIKEYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListApiKeys',
    full_name='tecton_proto.metadataservice.MetadataService.ListApiKeys',
    index=39,
    containing_service=None,
    input_type=_LISTAPIKEYSREQUEST,
    output_type=_LISTAPIKEYSRESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSavedFeatureDataFrame',
    full_name='tecton_proto.metadataservice.MetadataService.CreateSavedFeatureDataFrame',
    index=40,
    containing_service=None,
    input_type=_CREATESAVEDFEATUREDATAFRAMEREQUEST,
    output_type=_CREATESAVEDFEATUREDATAFRAMERESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ArchiveSavedFeatureDataFrame',
    full_name='tecton_proto.metadataservice.MetadataService.ArchiveSavedFeatureDataFrame',
    index=41,
    containing_service=None,
    input_type=_ARCHIVESAVEDFEATUREDATAFRAMEREQUEST,
    output_type=_ARCHIVESAVEDFEATUREDATAFRAMERESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSavedFeatureDataFrame',
    full_name='tecton_proto.metadataservice.MetadataService.GetSavedFeatureDataFrame',
    index=42,
    containing_service=None,
    input_type=_GETSAVEDFEATUREDATAFRAMEREQUEST,
    output_type=_GETSAVEDFEATUREDATAFRAMERESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllSavedFeatureDataFrames',
    full_name='tecton_proto.metadataservice.MetadataService.GetAllSavedFeatureDataFrames',
    index=43,
    containing_service=None,
    input_type=_GETALLSAVEDFEATUREDATAFRAMESREQUEST,
    output_type=_GETALLSAVEDFEATUREDATAFRAMESRESPONSE,
    serialized_options=b'\202\323\344\223\002:\"5/v1/metadata-service/get-all-saved-feature-dataframes:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNewIngestDataframeInfo',
    full_name='tecton_proto.metadataservice.MetadataService.GetNewIngestDataframeInfo',
    index=44,
    containing_service=None,
    input_type=_GETNEWINGESTDATAFRAMEINFOREQUEST,
    output_type=_GETNEWINGESTDATAFRAMEINFORESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IngestDataframe',
    full_name='tecton_proto.metadataservice.MetadataService.IngestDataframe',
    index=45,
    containing_service=None,
    input_type=_INGESTDATAFRAMEREQUEST,
    output_type=_INGESTDATAFRAMERESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClusterAdminInfo',
    full_name='tecton_proto.metadataservice.MetadataService.GetClusterAdminInfo',
    index=46,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCLUSTERADMININFORESPONSE,
    serialized_options=b'\202\323\344\223\0020\"+/v1/metadata-service/get-cluster-admin-info:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateClusterUser',
    full_name='tecton_proto.metadataservice.MetadataService.CreateClusterUser',
    index=47,
    containing_service=None,
    input_type=_CREATECLUSTERUSERREQUEST,
    output_type=_CREATECLUSTERUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002-\"(/v1/metadata-service/create-cluster-user:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteClusterUser',
    full_name='tecton_proto.metadataservice.MetadataService.DeleteClusterUser',
    index=48,
    containing_service=None,
    input_type=_DELETECLUSTERUSERREQUEST,
    output_type=_DELETECLUSTERUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002-\"(/v1/metadata-service/delete-cluster-user:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClusterUserAction',
    full_name='tecton_proto.metadataservice.MetadataService.ClusterUserAction',
    index=49,
    containing_service=None,
    input_type=_CLUSTERUSERACTIONREQUEST,
    output_type=_CLUSTERUSERACTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002-\"(/v1/metadata-service/cluster-user-action:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserDeploymentSettings',
    full_name='tecton_proto.metadataservice.MetadataService.GetUserDeploymentSettings',
    index=50,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETUSERDEPLOYMENTSETTINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\"1/v1/metadata-service/get-user-deployment-settings:\001*\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUserDeploymentSettings',
    full_name='tecton_proto.metadataservice.MetadataService.UpdateUserDeploymentSettings',
    index=51,
    containing_service=None,
    input_type=_UPDATEUSERDEPLOYMENTSETTINGSREQUEST,
    output_type=_UPDATEUSERDEPLOYMENTSETTINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\"4/v1/metadata-service/update-user-deployment-settings:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetInternalSparkClusterStatus',
    full_name='tecton_proto.metadataservice.MetadataService.GetInternalSparkClusterStatus',
    index=52,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETINTERNALSPARKCLUSTERSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\002;\"6/v1/metadata-service/get-internal-spark-cluster-status:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeleteEntitiesInfo',
    full_name='tecton_proto.metadataservice.MetadataService.GetDeleteEntitiesInfo',
    index=53,
    containing_service=None,
    input_type=_GETDELETEENTITIESINFOREQUEST,
    output_type=_GETDELETEENTITIESINFORESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEntities',
    full_name='tecton_proto.metadataservice.MetadataService.DeleteEntities',
    index=54,
    containing_service=None,
    input_type=_DELETEENTITIESREQUEST,
    output_type=_DELETEENTITIESRESPONSE,
    serialized_options=b'\200\265\030\001',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METADATASERVICE)

DESCRIPTOR.services_by_name['MetadataService'] = _METADATASERVICE

# @@protoc_insertion_point(module_scope)
